@@ -6,33 +6,14 @@
  *  @author     Masaki Fujimoto <fujimoto@php.net>
  *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
  *  @package    Ethna
- *  @version    $Id$
+ *  @version    $Id: Ethna.php 572 2008-06-08 01:31:35Z mumumu-org $
  */
 
-//
-//  PEAR OS_WINDOWS constant replacement.
-//
-//  PEAR の OS_WINDOWS 定数は、defined関数で
-//  既に定義されているかをチェックしていない。
-//  よって require_once 'PEAR.php' とすると
-//  E_NOTICEが出ることから、Windows環境判定用
-//  として独自の定数を定義する
-//
-if (substr(PHP_OS, 0, 3) == 'WIN'
- && !defined('ETHNA_OS_WINDOWS')) {
-    define('ETHNA_OS_WINDOWS', true);
-} elseif (!defined('ETHNA_OS_WINDOWS')) {
-    define('ETHNA_OS_WINDOWS', false);
-}
-//  PHP 5.1.0 以降向けの変更
-//  date.timezone が設定されていないと
-//  E_STRICT|WARNING が発生する
-if (!ini_get('date.timezone')) {
-    ini_set('date.timezone', 'Asia/Tokyo');
-}
+/** Ethna depends on PEAR */
+require_once 'PEAR.php';
 
 if (!defined('PATH_SEPARATOR')) {
-    if (ETHNA_OS_WINDOWS) {
+    if (OS_WINDOWS) {
         /** include_path separator(Windows) */
         define('PATH_SEPARATOR', ';');
     } else {
@@ -41,7 +22,7 @@ if (!defined('PATH_SEPARATOR')) {
     }
 }
 if (!defined('DIRECTORY_SEPARATOR')) {
-    if (ETHNA_OS_WINDOWS) {
+    if (OS_WINDOWS) {
         /** directory separator(Windows) */
         define('DIRECTORY_SEPARATOR', '\\');
     } else {
@@ -51,13 +32,7 @@ if (!defined('DIRECTORY_SEPARATOR')) {
 }
 
 /** バージョン定義 */
-define('ETHNA_VERSION', '2.5.0');
-
-/**
- * ダミーのエラーモード
- * PEAR非依存、かつ互換性を維持するためのもの
- */
-define('ETHNA_ERROR_DUMMY', 'dummy');
+define('ETHNA_VERSION', '2.5.0-preview1');
 
 /** Ethnaベースディレクトリ定義 */
 define('ETHNA_BASE', dirname(__FILE__));
@@ -304,13 +279,10 @@ define('E_PLUGIN_NOTFOUND', 196);
 /** エラーコード: プラグインエラー(その他) */
 define('E_PLUGIN_GENERAL', 197);
 
-/** PHP 5との互換保持定義 */
 if (defined('E_STRICT') == false) {
+    /** PHP 5との互換保持定義 */
     define('E_STRICT', 2048);
 }
-if (defined('E_DEPRECATED') == false) {
-    define('E_DEPRECATED', 8192);
-}
 
 /** Ethnaグローバル変数: エラーコールバック関数 */
 $GLOBALS['_Ethna_error_callback_list'] = array();
@@ -327,37 +299,13 @@ $GLOBALS['_Ethna_error_message_list'] = array();
  *  @access     public
  *  @package    Ethna
  */
-class Ethna
+class Ethna extends PEAR
 {
-    /**
-     *  渡されたオブジェクトが Ethna_Error オブジェクト
-     *  またはそのサブクラスのオブジェクトかどうかチェックします。
-     *
-     *  @param mixed  $data    チェックする変数
-     *  @param mixed  $msgcode チェックするエラーメッセージまたはエラーコード  
-     *  @return mixed 変数が、Ethna_Error の場合に TRUEを返します。
-     *                第2引数が設定された場合は、さらに 所与された $msgcode
-     *                を含む場合のみ TRUEを返します。
-     *  @static
+    /**#@+
+     *  @access private
      */
-    function isError($data, $msgcode = NULL)
-    {
-        if (!is_object($data)) {
-            return false;
-        }
 
-        $class_name = get_class($data);
-        if (strcasecmp($class_name, 'Ethna_Error') === 0
-         || is_subclass_of($data, 'Ethna_Error')) {
-            if ($msgcode == NULL) {
-                return true;
-            } elseif ($data->getCode() == $msgcode) {
-                return true;
-            }
-        }
-
-        return false;
-    }
+    /**#@-*/
 
     /**
      *  Ethna_Errorオブジェクトを生成する(エラーレベル:E_USER_ERROR)
@@ -376,8 +324,7 @@ class Ethna
                 $userinfo = $userinfo[0];
             }
         }
-        $error = new Ethna_Error($message, $code, ETHNA_ERROR_DUMMY, E_USER_ERROR, $userinfo, 'Ethna_Error');
-        return $error;
+        return PEAR::raiseError($message, $code, PEAR_ERROR_RETURN, E_USER_ERROR, $userinfo, 'Ethna_Error');
     }
 
     /**
@@ -397,9 +344,7 @@ class Ethna
                 $userinfo = $userinfo[0];
             }
         }
-
-        $error = new Ethna_Error($message, $code, ETHNA_ERROR_DUMMY, E_USER_WARNING, $userinfo, 'Ethna_Error');
-        return $error;
+        return PEAR::raiseError($message, $code, PEAR_ERROR_RETURN, E_USER_WARNING, $userinfo, 'Ethna_Error');
     }
 
     /**
@@ -419,9 +364,7 @@ class Ethna
                 $userinfo = $userinfo[0];
             }
         }
-
-        $error = new Ethna_Error($message, $code, ETHNA_ERROR_DUMMY, E_USER_NOTICE, $userinfo, 'Ethna_Error');
-        return $error;
+        return PEAR::raiseError($message, $code, PEAR_ERROR_RETURN, E_USER_NOTICE, $userinfo, 'Ethna_Error');
     }
 
     /**
@@ -466,13 +409,11 @@ class Ethna
 
                 // perform some more checks?
                 $object->$method($error);
-            } else {  
-                //  call statically
+            } else {
                 call_user_func($callback, $error);
             }
         }
     }
 }
 // }}}
-
 ?>
