@@ -7,36 +7,14 @@
  *  @author     Kazuhiro Hosoi <hosoi@gree.co.jp>
  *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
  *  @package    Ethna
- *  @version    $Id$
+ *  @version    $Id: ethna_run_test.php 488 2007-12-13 22:11:18Z mumumu-org $
  */
 
-/** Ethnaインストールルートディレクトリ */
-define('ETHNA_INSTALL_BASE', dirname(dirname(__FILE__)));
-
-$symlink_filename = null;
-
-/** シンボリックリンクをインストールディレクトリの親に張る */
-/** symlink 関数は 5.3.0 以前では Windows 上で動作しない   */
-/** が、Cygwinでテストするため問題はない。                 */
-if (basename(ETHNA_INSTALL_BASE) != 'Ethna') {
-    $symlink_filename = dirname(ETHNA_INSTALL_BASE) . "/Ethna";
-    if (!file_exists($symlink_filename)) {
-        symlink(ETHNA_INSTALL_BASE, $symlink_filename);
-    } else {
-        if (!is_link($symlink_filename)
-            || realpath($symlink_filename) != ETHNA_INSTALL_BASE) {
-            echo "Base dir 'Ethna' exists and it's not ETHNA_INSTALL_BASE.\n";
-            exit(1);
-        }
-    }
-}
-
-/** テストケースがあるディレクトリ */
-$test_dir = ETHNA_INSTALL_BASE . '/test';
+/** アプリケーションベースディレクトリ */
+define('BASE', dirname(dirname(__FILE__)));
 
 /** include_pathの設定(このtest runnerがあるディレクトリを追加) */
-//ini_set('include_path', realpath(ETHNA_INSTALL_BASE . '/class') . PATH_SEPARATOR . ini_get('include_path'));
-ini_set('include_path', realpath(dirname(ETHNA_INSTALL_BASE)) . PATH_SEPARATOR . ini_get('include_path'));
+ini_set('include_path', dirname(BASE) . PATH_SEPARATOR . ini_get('include_path'));
 
 /** Ethna関連クラスのインクルード */
 require_once 'Ethna/Ethna.php';
@@ -44,16 +22,18 @@ require_once 'Ethna/Ethna.php';
 /** SimpleTestのインクルード */
 require_once 'simpletest/unit_tester.php';
 require_once 'simpletest/reporter.php';
-require_once $test_dir . '/TextDetailReporter.php';
-require_once $test_dir . '/Ethna_UnitTestBase.php';
+require_once 'Ethna/test/TextDetailReporter.php';
+require_once 'Ethna/test/Ethna_UnitTestBase.php';
+
+/** テストケースがあるディレクトリ */
+$test_dir = ETHNA_BASE . '/test';
 
 $test = &new GroupTest('Ethna All tests');
 
 // テストケースのファイルリストを取得
-require_once 'Ethna/class/Ethna_Getopt.php';
-$opt = new Ethna_Getopt();
-$args = $opt->readPHPArgv();
-list($args, $opts) = $opt->getopt($args, '', array());
+require_once 'Console/Getopt.php';
+$args = Console_Getopt::readPHPArgv();
+list($args, $opts) = Console_Getopt::getopt2($args, '', array());
 array_shift($opts);
 if (count($opts) > 0) {
     $file_list = $opts;
@@ -67,12 +47,9 @@ foreach ($file_list as $file) {
 }
 
 // 結果をコマンドラインに出力
+//$test->run(new TextReporter());
 $test->run(new TextDetailReporter());
 
-if ($symlink_filename !== null && is_link($symlink_filename)) {
-    unlink($symlink_filename);
-}
-
 //{{{ getFileList
 /**
  * getFileList
@@ -112,5 +89,4 @@ function getFileList($dir_path)
     return $file_list;
 }
 //}}}
-
 ?>
