@@ -6,7 +6,7 @@
  *  @author     Masaki Fujimoto <fujimoto@php.net>
  *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
  *  @package    Ethna
- *  @version    $Id$
+ *  @version    $Id: Ethna_ActionClass.php 488 2007-12-13 22:11:18Z mumumu-org $
  */
 
 // {{{ Ethna_ActionClass
@@ -50,9 +50,6 @@ class Ethna_ActionClass
     /** @var    object  Ethna_Plugin        プラグインオブジェクト */
     var $plugin;
 
-    /** @var    object  Ethna_Logger    ログオブジェクト */
-    var $logger;
-
     /**#@-*/
 
     /**
@@ -76,7 +73,6 @@ class Ethna_ActionClass
 
         $this->session =& $this->backend->getSession();
         $this->plugin =& $this->backend->getPlugin();
-        $this->logger =& $this->backend->getLogger();
     }
 
     /**
