@@ -6,7 +6,7 @@
  *  @author     Masaki Fujimoto <fujimoto@php.net>
  *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
  *  @package    Ethna
- *  @version    $Id$
+ *  @version    $Id: Ethna_ActionError.php 493 2008-04-04 15:09:44Z mumumu-org $
  */
 
 // {{{ Ethna_ActionError
@@ -199,7 +199,7 @@ class Ethna_ActionError
      */
     function &_getActionForm()
     {
-        if (isset($this->action_form) == false) {
+        if (is_null($this->action_form)) {
             $controller =& Ethna_Controller::getInstance();
             $this->action_form =& $controller->getActionForm();
         }
