@@ -6,7 +6,7 @@
  *  @author     Masaki Fujimoto <fujimoto@php.net>
  *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
  *  @package    Ethna
- *  @version    $Id$
+ *  @version    $Id: Ethna_ActionForm.php 577 2008-06-12 00:24:37Z mumumu-org $
  */
 
 /** 定型フィルタ: 半角入力 */
@@ -80,9 +80,6 @@ class Ethna_ActionForm
     /** @var    array   アプリケーションオブジェクト(helper)で利用しないフォーム名 */
     var $helper_skip_form = array();
 
-    /** @var    int   フォーム配列で使用可能な深さの上限 */
-    var $max_form_deps = 10;
-
     /**#@-*/
 
     /**
@@ -116,7 +113,7 @@ class Ethna_ActionForm
         }
 
         // フォーム値定義の設定
-        $this->_setFormDef_HelperObj();
+        $this->_setFormDef_Helper();
         $this->_setFormDef();
 
         // 省略値補正
@@ -138,7 +135,10 @@ class Ethna_ActionForm
      */
     function get($name)
     {
-        return $this->_getVarsByFormName($this->form_vars, $name);
+        if (isset($this->form_vars[$name])) {
+            return $this->form_vars[$name];
+        }
+        return null;
     }
 
     /**
@@ -181,125 +181,12 @@ class Ethna_ActionForm
         // try message catalog
         return $this->i18n->get($name);
     }
-    
-    /**
-     *  フォーム名に対応するキーの配列を返す
-     *
-     *  @access private
-     *  @param  string  $name   フォーム名
-     *  @return array   キーの配列
-     */
-    function _getFormNameArray($name)
-    {
-        // 多次元配列を指定した場合
-        if (preg_match('/^.*\[[^\]]+\]$/', $name)) { 
-            $buff = preg_replace('/\]\[/', '[', $name); // hoge[foo][bar] => hoge[foo[bar]
-            $buff = preg_replace('/\]/', "", $buff);    // hoge][foo[bar] => hoge[foo[bar
-            $ret = explode('[', $buff);                 // hoge[foo[bar   => array('hoge', 'foo', 'var')
-        } else {
-            // 多次元配列を指定していない場合
-            $ret = array($name);
-        }
-        return $ret;
-    }
-
-    /**
-     *  配列の中からキーで指定された要素を取り出す
-     *
-     *  @access private
-     *  @param  array   &$target    対象とする配列
-     *  @param  string  $nane       キー
-     *  @return string  指定された要素
-     */
-    function _getVarsByFormName(&$target, $name)
-    {
-        $keys = $this->_getFormNameArray($name);
-        return $this->_getVarsByKeys($target, $keys);
-    }
-
-    /**
-     *  配列の中にキーで指定された要素を登録する
-     *  フォーム定義にキーがあるかどうかは無関係に登録します
-     *
-     *  @access private
-     *  @param  array   &$target    対象とする配列
-     *  @param  string  $nane       キー
-     *  @param  mixde   $value      登録する値
-     */
-    function _setVarsByFormName(&$target, $name, $vars)
-    {
-        $keys = $this->_getFormNameArray($name);
-        $this->_setVarsByKeys($target, $keys, $vars);
-    }
-    
-    /**
-     *  配列の中からキーで指定された要素を取り出す
-     *
-     *  @access private
-     *  @param  array   &$target    対象とする配列
-     *  @param  array   $keys       キーの配列
-     *  @return string  指定された要素
-     */
-    function _getVarsByKeys(&$target, $keys)
-    {
-        $count = count($keys);
-        if ($count == 0) { // 探索完了
-            return $target;
-        } elseif ($this->max_form_deps + 1 <= $count) { // 深すぎる配列を制限する
-            return null;
-        }
-
-        // まだ探索するキーが残っている
-        $curval = array_shift($keys);
-        if (is_array($target) && array_key_exists($curval, $target)) {
-            return $this->_getVarsByKeys($target[$curval], $keys);
-        }
-        return null;
-    }
-
-    function _setVarsByKeys(&$target, $keys, &$var)
-    {
-        $count = count($keys);
-        if ($count == 0) { // 探索完了
-            $target = $var;
-            return;
-        } elseif ($this->max_form_deps + 1 <= $count) { // 深すぎる配列を制限する
-            return;
-        }
-
-        // まだ探索するキーが残っている
-        $curval = array_shift($keys);
-        if (is_array($target)) {
-            if (! array_key_exists($curval, $target)) {
-                $target[$curval] = null;
-            }
-        } else {
-            $target = array($curval => null);
-        }
-
-        $this->_setVarsByKeys($target[$curval], $keys, $var);
-    }
-
-    /**
-     *  $_FILESの中からキーで指定された要素を取り出す
-     *
-     *  @access private
-     *  @param  array   &$target    対象とする配列
-     *  @param  string  $nane       キー
-     *  @param  string  $key        $_FILESに含まれる項目(tmp_name等)
-     *  @return string  指定された要素
-     */
-    function _getFilesInfoByFormName(&$target, $name, $key)
-    {
-        $form_keys = $this->_getFormNameArray($name);
-        array_splice($form_keys, 1, 0, $key);
-        return $this->_getVarsByKeys($target, $form_keys);
-    }
 
     /**
      *  ユーザから送信されたフォーム値をフォーム値定義に従ってインポートする
      *
      *  @access public
+     *  @todo   多次元の配列への対応
      */
     function setFormVars()
     {
@@ -311,42 +198,28 @@ class Ethna_ActionForm
             $http_vars =& $_GET;
         }
 
-        //
-        //  ethna_fid というフォーム値は、フォーム定義に関わらず受け入れる
-        //  これは、submitされたフォームを識別するために使われる
-        //  null の場合は、以下の場合である
-        //
-        //  1. フォームヘルパが使われていない
-        //  2. 画面の初期表示などで、submitされなかった
-        //  3. {form name=...} が未設定である
-        //
-        $this->form_vars['ethna_fid'] = (isset($http_vars['ethna_fid']) == false
-                                      || is_null($http_vars['ethna_fid']))
-                                      ? null
-                                      : $http_vars['ethna_fid'];
-
         foreach ($this->form as $name => $def) {
             $type = is_array($def['type']) ? $def['type'][0] : $def['type'];
             if ($type == VAR_TYPE_FILE) {
                 // ファイルの場合
 
                 // 値の有無の検査
-                if (is_null($this->_getFilesInfoByFormName($_FILES, $name, 'tmp_name'))) {
-                    $this->set($name, null);
+                if (isset($_FILES[$name]) == false || is_null($_FILES[$name])) {
+                    $this->form_vars[$name] = null;
                     continue;
                 }
 
                 // 配列構造の検査
                 if (is_array($def['type'])) {
-                    if (is_array($this->_getFilesInfoByFormName($_FILES, $name, 'tmp_name')) == false) {
+                    if (is_array($_FILES[$name]['tmp_name']) == false) {
                         $this->handleError($name, E_FORM_WRONGTYPE_ARRAY);
-                        $this->set($name, null);
+                        $this->form_vars[$name] = null;
                         continue;
                     }
                 } else {
-                    if (is_array($this->_getFilesInfoByFormName($_FILES, $name, 'tmp_name'))) {
+                    if (is_array($_FILES[$name]['tmp_name'])) {
                         $this->handleError($name, E_FORM_WRONGTYPE_SCALAR);
-                        $this->set($name, null);
+                        $this->form_vars[$name] = null;
                         continue;
                     }
                 }
@@ -355,70 +228,62 @@ class Ethna_ActionForm
                 if (is_array($def['type'])) {
                     $files = array();
                     // ファイルデータを再構成
-                    foreach (array_keys($this->_getFilesInfoByFormName($_FILES, $name, 'name')) as $key) {
+                    foreach (array_keys($_FILES[$name]['name']) as $key) {
                         $files[$key] = array();
-                        $files[$key]['name'] = $this->_getFilesInfoByFormName($_FILES, $name."[".$key."]", 'name');
-                        $files[$key]['type'] = $this->_getFilesInfoByFormName($_FILES, $name."[".$key."]", 'type');
-                        $files[$key]['size'] = $this->_getFilesInfoByFormName($_FILES, $name."[".$key."]", 'size');
-                        $files[$key]['tmp_name'] = $this->_getFilesInfoByFormName($_FILES, $name."[".$key."]", 'tmp_name');
-                        if ($this->_getFilesInfoByFormName($_FILES, $name."[".$key."]", 'error') == null) {
+                        $files[$key]['name'] = $_FILES[$name]['name'][$key];
+                        $files[$key]['type'] = $_FILES[$name]['type'][$key];
+                        $files[$key]['size'] = $_FILES[$name]['size'][$key];
+                        $files[$key]['tmp_name'] = $_FILES[$name]['tmp_name'][$key];
+                        if (isset($_FILES[$name]['error']) == false) {
                             // PHP 4.2.0 以前
                             $files[$key]['error'] = 0;
                         } else {
-                            $files[$key]['error'] = $this->_getFilesInfoByFormName($_FILES, $name."[".$key."]", 'error');
+                            $files[$key]['error'] = $_FILES[$name]['error'][$key];
                         }
                     }
                 } else {
-                    $files['name'] = $this->_getFilesInfoByFormName($_FILES, $name, 'name');
-                    $files['type'] = $this->_getFilesInfoByFormName($_FILES, $name, 'type');
-                    $files['size'] = $this->_getFilesInfoByFormName($_FILES, $name, 'size');
-                    $files['tmp_name'] = $this->_getFilesInfoByFormName($_FILES, $name, 'tmp_name');
-                    if ($this->_getFilesInfoByFormName($_FILES, $name, 'error') == null) {
-                        // PHP 4.2.0 以前
+                    $files = $_FILES[$name];
+                    if (isset($files['error']) == false) {
                         $files['error'] = 0;
-                    } else {
-                        $files['error'] = $this->_getFilesInfoByFormName($_FILES, $name, 'error');
                     }
                 }
 
                 // 値のインポート
-                $this->set($name, $files);
+                $this->form_vars[$name] = $files;
 
             } else {
                 // ファイル以外の場合
 
-                $target_var = $this->_getVarsByFormName($http_vars, $name);
-
                 // 値の有無の検査
-                if (isset($target_var) == false
-                    || is_null($target_var)) {
-                    $this->set($name, null);
+                if (isset($http_vars[$name]) == false
+                    || is_null($http_vars[$name])) {
+                    $this->form_vars[$name] = null;
                     if (isset($http_vars["{$name}_x"])
-                     && isset($http_vars["{$name}_y"])) {
+                        && isset($http_vars["{$name}_y"])) {
                         // 以前の仕様に合わせる
-                        $this->set($name, $http_vars["{$name}_x"]);
+                        $this->form_vars[$name] = $http_vars["{$name}_x"];
                     }
                     continue;
                 }
 
                 // 配列構造の検査
                 if (is_array($def['type'])) {
-                    if (is_array($target_var) == false) {
+                    if (is_array($http_vars[$name]) == false) {
                         // 厳密には、この配列の各要素はスカラーであるべき
                         $this->handleError($name, E_FORM_WRONGTYPE_ARRAY);
-                        $this->set($name, null);
+                        $this->form_vars[$name] = null;
                         continue;
                     }
                 } else {
-                    if (is_array($target_var)) {
+                    if (is_array($http_vars[$name])) {
                         $this->handleError($name, E_FORM_WRONGTYPE_SCALAR);
-                        $this->set($name, null);
+                        $this->form_vars[$name] = null;
                         continue;
                     }
                 }
 
                 // 値のインポート
-                $this->set($name, $target_var);
+                $this->form_vars[$name] = $http_vars[$name];
             }
         }
     }
@@ -442,7 +307,7 @@ class Ethna_ActionForm
      */
     function set($name, $value)
     {
-        $this->_setVarsByFormName($this->form_vars, $name, $value);
+        $this->form_vars[$name] = $value;
     }
 
     /**
@@ -458,9 +323,8 @@ class Ethna_ActionForm
         if (is_null($name)) {
             $this->form = $value;
         }
-        else {
-            $this->form[$name] = $value;
-        }
+
+        $this->form[$name] = $value;
     }
 
     /**
@@ -641,24 +505,29 @@ class Ethna_ActionForm
         if ($this->form[$form_name]['type'] != VAR_TYPE_FILE) {
             
             //    入力値とフィルタ定義を取り出す
-            $form_var = $this->get($form_name);
+            $form_var = (isset($this->form_vars[$form_name]))
+                      ? $this->form_vars[$form_name]
+                      : null;
             $filter = (isset($this->form[$form_name]['filter']))
                     ? $this->form[$form_name]['filter']
                     : null;
 
             //    フィルタを適用
             if (is_array($this->form[$form_name]['type']) == false) {
-                $this->set($form_name, $this->_filter($form_var, $filter));
+                $this->form_vars[$form_name]
+                    = $this->_filter($form_var, $filter);
             } else if ($form_var != null) {  //  配列の場合
-                foreach (array_keys($form_var) as $key) {
-                    $this->set($form_name."[".$key."]", $this->_filter($form_var[$key], $filter));
+                foreach (array_keys($this->form_vars[$form_name]) as $key) {
+                    $this->form_vars[$form_name][$key]
+                        = $this->_filter($this->form_vars[$form_name][$key], $filter);
                 }
             } else {  //  配列で値が空の場合
-                $this->set($form_name, $this->_filter($form_var, $filter));
+                $this->form_vars[$form_name]
+                    = $this->_filter($form_var, $filter);
             }
         }
 
-        $form_vars = $this->get($form_name);
+        $form_vars = $this->form_vars[$form_name];
         $plugin = $this->_getPluginDef($form_name);
 
         // type のチェックを処理の最初に追加
@@ -763,7 +632,7 @@ class Ethna_ActionForm
      */
     function check($name)
     {
-        if (is_null($this->get($name)) || $this->get($name) === "") {
+        if (is_null($this->form_vars[$name]) || $this->form_vars[$name] === "") {
             return null;
         }
 
@@ -771,7 +640,7 @@ class Ethna_ActionForm
         $c =& Ethna_Controller::getInstance();
         $this->backend =& $c->getBackend();
 
-        return to_array($this->get($name));
+        return to_array($this->form_vars[$name]);
     }
 
     /**
@@ -784,7 +653,7 @@ class Ethna_ActionForm
     function &checkVendorChar($name)
     {
         $null = null;
-        $string = $this->get($name);
+        $string = $this->form_vars[$name];
 
         for ($i = 0; $i < strlen($string); $i++) {
             /* JIS13区のみチェック */
@@ -922,27 +791,15 @@ class Ethna_ActionForm
                 continue;
             }
 
-            $form_value = $this->get($key);
+            $form_value = $this->form_vars[$key];
             if (is_array($value['type'])) {
                 $form_array = true;
-                //  フォーム定義が配列なのにスカラーが
-                //  渡ってきた場合は値を配列扱いとし、
-                //  フォーム定義を尊重する
-                if (is_array($form_value) == false) {
-                    $form_value = array($form_value);
-                }
             } else {
-                //  フォーム定義がスカラーなのに配列が渡ってきた
-                //  場合は救いようがないのでNOTICE扱いとし、タグも出力しない
-                if (is_array($form_value)) {
-                    $this->handleError($key, E_FORM_WRONGTYPE_ARRAY);
-                    continue;
-                }
                 $form_value = array($form_value);
                 $form_array = false;
             }
 
-            if (is_null($this->get($key))) {
+            if (is_null($this->form_vars[$key])) {
                 // フォーム値が送られていない場合はそもそもhiddenタグを出力しない
                 continue;
             }
@@ -955,9 +812,7 @@ class Ethna_ActionForm
                 }
                 $hidden_vars .=
                     sprintf("<input type=\"hidden\" name=\"%s\" value=\"%s\" />\n",
-                            htmlspecialchars($form_name, ENT_QUOTES),
-                            htmlspecialchars($v, ENT_QUOTES)
-                    );
+                    $form_name, htmlspecialchars($v, ENT_QUOTES));
             }
         }
         return $hidden_vars;
@@ -995,14 +850,11 @@ class Ethna_ActionForm
             E_FORM_MAX_STRING   => 'max_error',
             E_FORM_REGEXP       => 'regexp_error',
         );
-        //   フォーム定義にエラーメッセージが定義されていれば
-        //   それを使う
         if (array_key_exists($code_map[$code], $def)) {
             $this->ae->add($name, $def[$code_map[$code]], $code);
             return;
         }
 
-        //   定義されていない場合は、内部のメッセージを使う
         if ($code == E_FORM_REQUIRED) {
             switch ($def['form_type']) {
             case FORM_TYPE_TEXT:
@@ -1242,49 +1094,11 @@ class Ethna_ActionForm
     }
 
     /**
-     *  フォーム定義変更用、ユーザ定義ヘルパメソッド
-     *
-     *  Ethna_ActionForm#prepare() が実行される前に
-     *  ユーザが動的にフォーム定義を変更したい場合に
-     *  このメソッドをオーバーライドします。
-     *
-     *  $this->backend も初期化済みのため、DBやセッション
-     *  の値に基づいてフォーム定義を変更することができます。
-     *
-     *  @access public 
-     */
-    function setFormDef_PreHelper()
-    {
-        //  TODO: override this method. 
-    }
-
-    /**
-     *  フォーム定義変更用、ユーザ定義ヘルパメソッド
-     *
-     *  フォームヘルパを使うときに、フォーム定義を動的に
-     *  変更したい場合に、このメソッドをオーバーライドします。
-     *
-     *  以下の定義をテンプレートで行った場合に呼び出されます。
-     *  
-     *  {form ethna_action=...} (ethna_action がない場合は呼び出されません)
-     *  {form_input action=...} (action がない場合は呼び出されません)
-     *
-     *  @access public 
-     */
-    function setFormDef_ViewHelper()
-    {
-        //   TODO: デフォルト実装は Ethna_ActionClass#prepare 前に
-        //   呼び出されるものと同じ。異なる場合にオーバライドする
-        $this->setFormDef_PreHelper(); 
-    }
-
-    /**
-     *  ヘルパオブジェクト(アプリケーションオブジェクト)
-     *  経由でのフォーム値定義を設定する
+     *  ヘルパオブジェクト経由でのフォーム値定義を設定する
      *
      *  @access protected
      */
-    function _setFormDef_HelperObj()
+    function _setFormDef_Helper()
     {
         foreach (array_keys($this->helper_app_object) as $key) {
             $object =& $this->helper_app_object[$key];
@@ -1324,13 +1138,6 @@ class Ethna_ActionForm
      */
     function _setFormDef()
     {
-        foreach ($this->form as $key => $value) {
-            if (is_numeric($key)) {
-                $this->form[$value] = array();
-                unset($this->form[$key]);
-            }
-        }
-
         foreach ($this->form as $key => $value) {
             if (array_key_exists($key, $this->form_template)
                 && is_array($this->form_template)) {
