@@ -6,7 +6,7 @@
  *  @author     Masaki Fujimoto <fujimoto@php.net>
  *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
  *  @package    Ethna
- *  @version    $Id$
+ *  @version    $Id: Ethna_AppObject.php 530 2008-05-12 12:50:34Z mumumu-org $
  */
 
 // {{{ Ethna_AppObject
@@ -17,8 +17,6 @@
  *  @access     public
  *  @package    Ethna
  *  @todo       複数テーブルの対応
- *  @todo       remove dependency on PEAR::DB
- *  @todo       quoteidentifier は Ethna_AppSQL に持っていくべき
  */
 class Ethna_AppObject
 {
@@ -48,13 +46,13 @@ class Ethna_AppObject
     /** @var    string  DB定義プレフィクス */
     var $db_prefix = null;
 
-    /** @var    array   テーブル定義。対応するDB上のテーブル名を指定します。*/
+    /** @var    array   テーブル定義 */
     var $table_def = null;
 
-    /** @var    array   プロパティ定義。テーブルのカラム定義を記述します。 */
+    /** @var    array   プロパティ定義 */
     var $prop_def = null;
 
-    /** @var    array   プロパティ。各カラムに対応する実際の値です。 */
+    /** @var    array   プロパティ */
     var $prop = null;
 
     /** @var    array   プロパティ(バックアップ) */
@@ -66,7 +64,7 @@ class Ethna_AppObject
     /** @var    array   プライマリキー定義 */
     var $id_def = null;
 
-    /** @var    int     オブジェクトID (プライマリーキーの値) */
+    /** @var    int     オブジェクトID */
     var $id = null;
 
     /**#@-*/
@@ -78,10 +76,9 @@ class Ethna_AppObject
      *
      *  @access public
      *  @param  object  Ethna_Backend   &$backend   Ethna_Backendオブジェクト
-     *  @param  mixed   $key_type   レコードを特定するためのカラム名
-     *                              (通常はプライマリーキーのフィールド)
-     *  @param  mixed   $key        レコードを特定するためのカラム値
-     *  @param  array   $prop       プロパティ(レコードの値)一覧
+     *  @param  mixed   $key_type   検索キー名
+     *  @param  mixed   $key        検索キー
+     *  @param  array   $prop       プロパティ一覧
      *  @return mixed   0:正常終了 -1:キー/プロパティ未指定 Ethna_Error:エラー
      */
     function Ethna_AppObject(&$backend, $key_type = null, $key = null, $prop = null)
@@ -107,16 +104,13 @@ class Ethna_AppObject
         // XXX: app objはdb typeを知らなくても動くべき
         $this->my_db_type = $this->my_db_rw->getType();
 
-        // テーブル定義自動取得
-        // 現在、記述可能なテーブルは常に一つで、primaryはtrue
+        // プロパティ定義自動取得
         if (is_null($this->table_def)) {
             $this->table_def = $this->_getTableDef();
         }
         if (is_string($this->table_def)) {
             $this->table_def = array($this->table_def => array('primary' => true));
         }
-        // プロパティ定義(テーブルのカラム定義)自動取得
-        // データベースから自動取得され、キャッシュされる
         if (is_null($this->prop_def)) {
             $this->prop_def = $this->_getPropDef();
         }
@@ -137,7 +131,7 @@ class Ethna_AppObject
                 $this->id_def = $k;
             } else if (is_array($this->id_def)) {
                 $this->id_def[] = $k;
-            } else {  // scalar の場合
+            } else {
                 $this->id_def = array($this->id_def, $k);
             }
         }
@@ -149,8 +143,6 @@ class Ethna_AppObject
         }
 
         // プロパティ設定
-        // $key_type, $key が指定されたらDBから値を取得し、設定する
-        // $prop が設定された場合はそれを設定する
         if (is_null($prop)) {
             $this->_setPropByDB($key_type, $key);
         } else {
@@ -159,7 +151,6 @@ class Ethna_AppObject
 
         $this->prop_backup = $this->prop;
 
-        //   プライマリーキーの値を設定
         if (is_array($this->id_def)) {
             $this->id = array();
             foreach ($this->id_def as $k) {
@@ -176,7 +167,6 @@ class Ethna_AppObject
     // {{{ isValid
     /**
      *  有効なオブジェクトかどうかを返す
-     *  プライマリーキーの値が設定されてなければ不正なオブジェクトです。
      *
      *  @access public
      *  @return bool    true:有効 false:無効
@@ -212,7 +202,7 @@ class Ethna_AppObject
 
     // {{{ getDef
     /**
-     *  オブジェクトのプロパティ定義(カラム定義)を返す
+     *  オブジェクトのプロパティ定義を返す
      *
      *  @access public
      *  @return array   オブジェクトのプロパティ定義
@@ -238,7 +228,7 @@ class Ethna_AppObject
 
     // {{{ getId
     /**
-     *  オブジェクトID(primary keyの値)を返す
+     *  オブジェクトIDを返す
      *
      *  @access public
      *  @return mixed   オブジェクトID
@@ -254,8 +244,8 @@ class Ethna_AppObject
      *  オブジェクトプロパティへのアクセサ(R)
      *
      *  @access public
-     *  @param  string  $key    プロパティ名(カラム名)
-     *  @return mixed   プロパティ(カラムの値)
+     *  @param  string  $key    プロパティ名
+     *  @return mixed   プロパティ
      */
     function get($key)
     {
@@ -273,14 +263,10 @@ class Ethna_AppObject
     // {{{ getName
     /**
      *  オブジェクトプロパティ表示名へのアクセサ
-     *  プロパティ値と、表示用の値が違う場合 (「県」等）に、
-     *  オーバーライドして下さい。
-     *
-     *  表示用の値を返す形で実装します。 
      *
      *  @access public
-     *  @param  string  $key    プロパティ(カラム)名
-     *  @return string  プロパティ(カラム)の表示名
+     *  @param  string  $key    プロパティ名
+     *  @return string  プロパティの表示名
      */
     function getName($key)
     {
@@ -288,14 +274,13 @@ class Ethna_AppObject
     }
     // }}}
 
+    // {{{ getLongName
     /**
      *  オブジェクトプロパティ表示名(詳細)へのアクセサ
-     *  プロパティ値と、表示用の値が違う場合 (「県」等）に、
-     *  オーバーライドして下さい。
      *
      *  @access public
-     *  @param  string  $key    プロパティ(カラム)名
-     *  @return string  プロパティ(カラム)の表示名(詳細)
+     *  @param  string  $key    プロパティ名
+     *  @return string  プロパティの表示名(詳細)
      */
     function getLongName($key)
     {
@@ -306,7 +291,6 @@ class Ethna_AppObject
     // {{{ getNameObject
     /**
      *  プロパティ表示名を格納した連想配列を取得する
-     *  すべての getName メソッドの戻り値を配列として返します。
      *
      *  @access public
      *  @return array   プロパティ表示名を格納した連想配列
@@ -325,10 +309,10 @@ class Ethna_AppObject
 
     // {{{ set
     /**
-     *  オブジェクトプロパティ(カラムに対応した値)を設定します。
+     *  オブジェクトプロパティへのアクセサ(W)
      *
      *  @access public
-     *  @param  string  $key    プロパティ(カラム)名
+     *  @param  string  $key    プロパティ名
      *  @param  string  $value  プロパティ値
      */
     function set($key, $value)
@@ -365,9 +349,7 @@ class Ethna_AppObject
      *  フォーム値からオブジェクトプロパティをインポートする
      *
      *  @access public
-     *  @param  int     $option インポートオプション
-     *                  OBJECT_IMPORT_IGNORE_NULL: フォーム値が送信されていない場合はスキップ
-     *                  OBJECT_IMPORT_CONVERT_NULL: フォーム値が送信されていない場合、空文字列に変換
+     *  @param  int     $option インポートオプション(OBJECT_IMPORT_IGNORE_NULL,...)
      */
     function importForm($option = null)
     {
@@ -404,15 +386,13 @@ class Ethna_AppObject
 
     // {{{ add
     /**
-     *  オブジェクトを追加する(INSERT)
+     *  オブジェクトを追加する
      *
      *  @access public
      *  @return mixed   0:正常終了 Ethna_Error:エラー
-     *  @todo remove dependency on PEAR::DB
      */
     function add()
     {
-        // primary key 定義が sequence の場合、
         // next idの取得: (pgsqlの場合のみ)
         // 取得できた場合はこのidを使う
         foreach (to_array($this->id_def) as $id_def) {
@@ -428,11 +408,9 @@ class Ethna_AppObject
             }
         }
 
-        //    INSERT 文を取得し、実行
         $sql = $this->_getSQL_Add();
         for ($i = 0; $i < 4; $i++) {
             $r =& $this->my_db_rw->query($sql);
-            //   エラーの場合 -> 重複キーエラーの場合はリトライ
             if (Ethna::isError($r)) {
                 if ($r->getCode() == E_DB_DUPENT) {
                     // 重複エラーキーの判別
@@ -472,7 +450,7 @@ class Ethna_AppObject
             }
         }
 
-        // ID(Primary Key)の値を設定
+        // IDの設定
         if (is_array($this->id_def)) {
             $this->id = array();
             foreach ($this->id_def as $k) {
@@ -494,17 +472,15 @@ class Ethna_AppObject
 
     // {{{ update
     /**
-     *  オブジェクトを更新する(UPDATE)
+     *  オブジェクトを更新する
      *
      *  @access public
      *  @return mixed   0:正常終了 Ethna_Error:エラー
-     *  @todo remove dependency on PEAR::DB
      */
     function update()
     {
         $sql = $this->_getSQL_Update();
-        //   エラーの場合 -> 重複キーエラーの場合はリトライ(4回)
-        for ($i = 0; $i < 4; $i++) {  //  magic number
+        for ($i = 0; $i < 4; $i++) {
             $r =& $this->my_db_rw->query($sql);
             if (Ethna::isError($r)) {
                 if ($r->getCode() == E_DB_DUPENT) {
@@ -554,14 +530,12 @@ class Ethna_AppObject
      *
      *  @access public
      *  @return mixed   0:正常終了 >0:オブジェクトID(追加時) Ethna_Error:エラー
-     *  @todo remove dependency on PEAR::DB
      */
     function replace()
     {
         $sql = $this->_getSQL_Select($this->getIdDef(), $this->getId());
 
-        //   重複機ーエラーの場合はリトライ(4回) 
-        for ($i = 0; $i < 3; $i++) {  // magic number
+        for ($i = 0; $i < 3; $i++) {
             $r = $this->my_db_rw->query($sql);
             if (Ethna::isError($r)) {
                 return $r;
@@ -587,11 +561,10 @@ class Ethna_AppObject
 
     // {{{ remove
     /**
-     *  オブジェクト(レコード)を削除する
+     *  オブジェクトを削除する
      *
      *  @access public
      *  @return mixed   0:正常終了 Ethna_Error:エラー
-     *  @todo remove dependency on PEAR::DB
      */
     function remove()
     {
@@ -611,23 +584,20 @@ class Ethna_AppObject
 
     // {{{ searchId
     /**
-     *  オブジェクトID(プライマリーキーの値)を検索する
+     *  オブジェクトIDを検索する
      *
      *  @access public
-     *  @param  array   $filter     WHERE検索条件(カラム名をキー、値には実際の条件値か、Ethna_AppSearchObjectを指定)
+     *  @param  array   $filter     検索条件
      *  @param  array   $order      検索結果ソート条件
-     *                              (カラム名をキー。値には、昇順の場合は OBJECT_SORT_ASC, 降順の場合は　OBJECT_SORT_DESC)
      *  @param  int     $offset     検索結果取得オフセット
      *  @param  int     $count      検索結果取得数
      *  @return mixed   array(0 => 検索条件にマッチした件数,
      *                  1 => $offset, $countにより指定された件数のオブジェクトID一覧)
      *                  Ethna_Error:エラー
-     *  TODO: remove dependency on PEAR::DB
      */
     function searchId($filter = null, $order = null, $offset = null, $count = null)
     {
-       //   プライマリーキー件数検索
-       if (is_null($offset) == false || is_null($count) == false) {
+        if (is_null($offset) == false || is_null($count) == false) {
             $sql = $this->_getSQL_SearchLength($filter);
             $r =& $this->my_db_ro->query($sql);
             if (Ethna::isError($r)) {
@@ -665,24 +635,21 @@ class Ethna_AppObject
 
     // {{{ searchProp
     /**
-     *  オブジェクトプロパティ(レコード)を検索する
+     *  オブジェクトプロパティを検索する
      *
      *  @access public
-     *  @param  array   $keys       取得するプロパティ(カラム名)
-     *  @param  array   $filter     WHERE検索条件(カラム名をキー、値には実際の条件値か、Ethna_AppSearchObjectを指定)
+     *  @param  array   $keys       取得するプロパティ
+     *  @param  array   $filter     検索条件
      *  @param  array   $order      検索結果ソート条件
-     *                              (カラム名をキー。値には、昇順の場合は OBJECT_SORT_ASC, 降順の場合は　OBJECT_SORT_DESC)
      *  @param  int     $offset     検索結果取得オフセット
      *  @param  int     $count      検索結果取得数
      *  @return mixed   array(0 => 検索条件にマッチした件数,
      *                  1 => $offset, $countにより指定された件数のオブジェクトプロパティ一覧)
      *                  Ethna_Error:エラー
-     *  TODO: remove dependency on PEAR::DB
      */
     function searchProp($keys = null, $filter = null, $order = null,
                         $offset = null, $count = null)
     {
-        //   プライマリーキー件数検索
         if (is_null($offset) == false || is_null($count) == false) {
             $sql = $this->_getSQL_SearchLength($filter);
             $r =& $this->my_db_ro->query($sql);
@@ -739,7 +706,6 @@ class Ethna_AppObject
      *  @access private
      *  @param  mixed   $key_type   検索キー名
      *  @param  mixed   $key        検索キー
-     *  TODO: depend on PEAR::DB
      */
     function _setPropByDB($key_type, $key)
     {
@@ -839,7 +805,6 @@ class Ethna_AppObject
      *
      *  @access private
      *  @return mixed   0:重複なし Ethna_Error:エラー array:重複キーのプロパティ名一覧
-     *  TODO: depend on PEAR::DB
      */
     function _getDuplicateKeyList()
     {
@@ -893,7 +858,7 @@ class Ethna_AppObject
      *  オブジェクトプロパティを取得するSQL文を構築する
      *
      *  @access private
-     *  @param  array   $key_type   検索キーとなるプロパティ(カラム)名一覧
+     *  @param  array   $key_type   キーとなるプロパティ名一覧
      *  @param  array   $key        $key_typeに対応するキー一覧
      *  @return string  SELECT文
      */
@@ -1107,29 +1072,22 @@ class Ethna_AppObject
      *  オブジェクト検索総数(offset, count除外)を取得するSQL文を構築する
      *
      *  @access private
-     *  @param  array   $filter     WHERE検索条件(カラム名をキー、値には実際の条件値か、Ethna_AppSearchObjectを指定)
+     *  @param  array   $filter     検索条件
      *  @return string  検索総数を取得するためのSELECT文
      *  @todo   my_db_typeの参照を廃止
      */
     function _getSQL_SearchLength($filter)
     {
-        // テーブル名をクォートした上で連結。
+        // テーブル
         $tables = implode(',',
             $this->my_db_ro->quoteIdentifier(array_keys($this->table_def)));
-
-        // プライマリーキー以外の検索条件が含まれていた
-        // 場合は、追加テーブルがあるとみなし、
-        // その解釈は _SQLPlugin_SearchTable に任せる
         if ($this->_isAdditionalField($filter)) {
             $tables .= " " . $this->_SQLPlugin_SearchTable();
         }
 
         $id_def = to_array($this->id_def);
-
-        //  テーブル名.プライマリーキー名
-        //  複数あった場合ははじめのものを使う
         $column_id = $this->my_db_ro->quoteIdentifier($this->_getPrimaryTable())
-             . "." . $this->my_db_ro->quoteIdentifier($id_def[0]);
+            . "." . $this->my_db_ro->quoteIdentifier($id_def[0]);
         $id_count = $this->my_db_ro->quoteIdentifier('id_count');
         $condition = $this->_getSQL_SearchCondition($filter);
 
@@ -1147,12 +1105,11 @@ class Ethna_AppObject
 
     // {{{ _getSQL_SearchId
     /**
-     *  オブジェクトID(プライマリーキー)検索を行うSQL文を構築する
+     *  オブジェクトID検索を行うSQL文を構築する
      *
      *  @access private
-     *  @param  array   $filter     WHERE検索条件(カラム名をキー、値には実際の条件値か、Ethna_AppSearchObjectを指定)
+     *  @param  array   $filter     検索条件
      *  @param  array   $order      検索結果ソート条件
-     *                              (カラム名をキー。値には、昇順の場合は OBJECT_SORT_ASC, 降順の場合は　OBJECT_SORT_DESC)
      *  @param  int     $offset     検索結果取得オフセット
      *  @param  int     $count      検索結果取得数
      *  @return string  オブジェクト検索を行うSELECT文
@@ -1209,10 +1166,9 @@ class Ethna_AppObject
      *  オブジェクトプロパティ検索を行うSQL文を構築する
      *
      *  @access private
-     *  @param  array   $keys       取得プロパティ(カラム名)一覧
-     *  @param  array   $filter     WHERE検索条件(カラム名をキー、値には実際の条件値か、Ethna_AppSearchObjectを指定)
+     *  @param  array   $keys       取得プロパティ一覧
+     *  @param  array   $filter     検索条件
      *  @param  array   $order      検索結果ソート条件
-     *                              (カラム名をキー。値には、昇順の場合は OBJECT_SORT_ASC, 降順の場合は　OBJECT_SORT_DESC)
      *  @param  int     $offset     検索結果取得オフセット
      *  @param  int     $count      検索結果取得数
      *  @return string  オブジェクト検索を行うSELECT文
@@ -1228,12 +1184,7 @@ class Ethna_AppObject
         }
         $p_table = $this->_getPrimaryTable();
 
-        //  検索用追加プロパティ
-        //  プライマリーキー以外の検索キーが含まれていた
-        //  場合は、その解釈を _SQLPlugin_SearchPropDef に任せる
-        //
-        //  これによって、複数のテーブルの条件を指定することが
-        //  できる(一応. ダサいけど)
+        // 検索用追加プロパティ
         if ($this->_isAdditionalField($filter)
             || $this->_isAdditionalField($order)) {
             $search_prop_def = $this->_SQLPlugin_SearchPropDef();
@@ -1250,7 +1201,6 @@ class Ethna_AppObject
                 $column .= ", ";
             }
             $t = isset($def[$key]['table']) ? $def[$key]['table'] : $p_table;
-            //   テーブル名.カラム名
             $column .= sprintf("%s.%s",
                                $this->my_db_ro->quoteIdentifier($t),
                                $this->my_db_ro->quoteIdentifier($key));
@@ -1294,7 +1244,7 @@ class Ethna_AppObject
      *  オブジェクト検索SQLの条件文を構築する
      *
      *  @access private
-     *  @param  array   $filter     WHERE検索条件(カラム名をキー、値には実際の条件値か、Ethna_AppSearchObjectを指定)
+     *  @param  array   $filter     検索条件
      *  @return string  オブジェクト検索の条件文(エラーならnull)
      */
     function _getSQL_SearchCondition($filter)
@@ -1305,12 +1255,7 @@ class Ethna_AppObject
 
         $p_table = $this->_getPrimaryTable();
 
-        //  検索用追加プロパティ
-        //  プライマリーキー以外の検索キーが含まれていた
-        //  場合は、その解釈を _SQLPlugin_SearchPropDef に任せる
-        //
-        //  これによって、複数のテーブルの条件を指定することが
-        //  できる(一応. ダサいけど)
+        // 検索用追加プロパティ
         if ($this->_isAdditionalField($filter)) {
             $search_prop_def = $this->_SQLPlugin_SearchPropDef();
         } else {
@@ -1333,9 +1278,6 @@ class Ethna_AppObject
 
             $t = isset($prop_def[$k]['table']) ? $prop_def[$k]['table'] : $p_table;
 
-            // 細かい条件を指定するには、Ethna_AppSearchObject
-            // を使う必要がある  文字列の場合は LIKE, 数値の場合
-            // は = 条件しか指定できないからである。
             if (is_object($v)) {
                 // Ethna_AppSearchObjectが指定されている場合
                 $condition .= $v->toString(
@@ -1442,8 +1384,7 @@ class Ethna_AppObject
 
     // {{{ _isAdditionalField
     /**
-     *  (検索条件|ソート条件)フィールドにプライマリーキー以外
-     *  の追加フィールドが含まれるかどうかを返す
+     *  (検索条件|ソート条件)フィールドに追加フィールドが含まれるかどうかを返す
      *
      *  @access private
      *  @param  array   $field  (検索条件|ソート条件)定義
@@ -1559,16 +1500,13 @@ class Ethna_AppObject
         $table = preg_replace('/^([A-Z])/e', "strtolower('\$1')", $table);
         $table = preg_replace('/([A-Z])/e', "'_' . strtolower('\$1')", $table);
 
-        //   JOIN には対応していないので、記述可能なテーブルは
-        //   常に一つ、かつ primary は trueになる
         return array($table => array('primary' => true));
     }
     // }}}
 
     // {{{ _getPropDef
     /**
-     *  プロパティ定義を取得します。キャッシュされている場合は、
-     *  そこから取得します。
+     *  プロパティ定義を取得する
      *
      *  @access protected
      *  @return array   プロパティ定義
