@@ -6,7 +6,7 @@
  *  @author     Masaki Fujimoto <fujimoto@php.net>
  *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
  *  @package    Ethna
- *  @version    $Id$
+ *  @version    $Id: Ethna_Config.php 611 2008-07-05 01:13:48Z mumumu-org $
  */
 
 // {{{ Ethna_Config
@@ -117,7 +117,7 @@ class Ethna_Config
 
         // デフォルト値設定
         if (isset($_SERVER['HTTP_HOST']) && isset($config['url']) == false) {
-            $config['url'] = sprintf("http://%s/", $_SERVER['HTTP_HOST']);
+            $config['url'] = sprintf("http://%s", $_SERVER['HTTP_HOST']);
         }
         if (isset($config['dsn']) == false) {
             $config['dsn'] = "";
