@@ -6,7 +6,7 @@
  *  @author     Masaki Fujimoto <fujimoto@php.net>
  *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
  *  @package    Ethna
- *  @version    $Id$
+ *  @version    $Id: Ethna_Controller.php 597 2008-06-30 14:43:54Z mumumu-org $
  */
 
 // {{{ Ethna_Controller
@@ -134,6 +134,25 @@ class Ethna_Controller
     /** @var    object  レンダラー */
     var $renderer = null;
 
+    /** @var    array   smarty modifier定義 */
+    var $smarty_modifier_plugin = array();
+
+    /** @var    array   smarty function定義 */
+    var $smarty_function_plugin = array();
+
+    /** @var    array   smarty block定義 */
+    var $smarty_block_plugin = array();
+
+    /** @var    array   smarty prefilter定義 */
+    var $smarty_prefilter_plugin = array();
+
+    /** @var    array   smarty postfilter定義 */
+    var $smarty_postfilter_plugin = array();
+
+    /** @var    array   smarty outputfilter定義 */
+    var $smarty_outputfilter_plugin = array();
+
+
     /** @var    array   フィルターチェイン(Ethna_Filterオブジェクトの配列) */
     var $filter_chain = array();
 
@@ -248,17 +267,6 @@ class Ethna_Controller
         $this->_activateEthnaManager();
     }
 
-    /**
-     *  アプリケーション実行後の後始末を行います。
-     *
-     *  @access protected
-     */
-    function end()
-    {
-        //  必要に応じてオーバライドして下さい。
-        $this->logger->end();
-    }
-
     /**
      *  (現在アクティブな)コントローラのインスタンスを返す
      *
@@ -305,7 +313,6 @@ class Ethna_Controller
 
         //    アプリケーションIDはクラス名のprefixともなるため、
         //    数字で始まっていてはいけない
-        //    @see http://www.php.net/manual/en/language.variables.php
         if (preg_match('/^[a-zA-Z][a-zA-Z0-9]*$/', $id) === 0) {
             $msg = (preg_match('/^[0-9]$/', $id[0]))
                  ? "Application ID must NOT start with Number.\n"
@@ -440,9 +447,7 @@ class Ethna_Controller
         $template = $this->getDirectory('template');
 
         // 言語別ディレクトリ
-        // _getDerfaultLanguageメソッドでロケールが指定されていた場合は、
-        // テンプレートディレクトリにも自動的にそれを付加する。
-        if (!empty($this->locale)) {
+        if (file_exists($template . '/' . $this->locale)) {
             $template .= '/' . $this->locale;
         }
 
@@ -505,6 +510,11 @@ class Ethna_Controller
      */
     function getDirectory($key)
     {
+        // for B.C.
+        if ($key == 'app' && isset($this->directory[$key]) == false) {
+            return BASE . '/app';
+        }
+
         if (isset($this->directory[$key]) == false) {
             return null;
         }
@@ -702,7 +712,7 @@ class Ethna_Controller
      *                  システムエンコーディング名,
      *                  クライアントエンコーディング名 の配列
      *                  (ロケール名は、ll_cc の形式。ll = 言語コード cc = 国コード)
-     *  @see http://www.gnu.org/software/gettext/manual/html_node/Locale-Names.html
+     *  @see http://www.gnu.org/software/gettext/manual/html_node/Locale-Names.html 
      */
     function getLanguage()
     {
@@ -792,7 +802,6 @@ class Ethna_Controller
     {
         $c =& new $class_name;
         $c->trigger($action_name, $fallback_action_name);
-        $c->end();
     }
 
     /**
@@ -809,7 +818,6 @@ class Ethna_Controller
         $c =& new $class_name(GATEWAY_CLI);
         $c->action_cli[$action_name] = array();
         $c->trigger($action_name, "", $enable_filter);
-        $c->end();
     }
 
     /**
@@ -826,7 +834,6 @@ class Ethna_Controller
 
         $c =& new $class_name(GATEWAY_XMLRPC);
         $c->trigger("", "", false);
-        $c->end();
     }
 
     /**
@@ -842,7 +849,6 @@ class Ethna_Controller
     {
         $c =& new $class_name(GATEWAY_SOAP);
         $c->trigger($action_name, $fallback_action_name);
-        $c->end();
     }
 
     /**
@@ -938,23 +944,21 @@ class Ethna_Controller
         }
         $this->action_name = $action_name;
 
-        // オブジェクト生成
-        $backend =& $this->getBackend();
-        $session =& $this->getSession();
-        $session->restore();
-
-        // 言語切り替えフックを呼ぶ
+        // ロケール/言語設定
         $this->_setLanguage($this->locale, $this->system_encoding, $this->client_encoding);
 
-        // アクションフォーム初期化
-        // フォーム定義、フォーム値設定
+        // オブジェクト生成
+        $backend =& $this->getBackend();
+
         $form_name = $this->getActionFormName($action_name);
         $this->action_form =& new $form_name($this);
-        $this->action_form->setFormDef_PreHelper();
         $this->action_form->setFormVars();
-        $backend->setActionForm($this->action_form);
 
         // バックエンド処理実行
+        $backend->setActionForm($this->action_form);
+
+        $session =& $this->getSession();
+        $session->restore();
         $forward_name = $backend->perform($action_name);
 
         // アクション実行後フィルタ
@@ -1018,7 +1022,7 @@ class Ethna_Controller
                 'version'       => 'xmlrpc',
                 'encoding'      => 'utf-8'
             )
-        );
+        ); 
 
         xmlrpc_server_register_method(
             $xmlrpc_server,
@@ -1269,9 +1273,9 @@ class Ethna_Controller
      */
     function getActionRequest($action, $type = "hidden")
     {
-        $s = null;
+        $s = null; 
         if ($type == "hidden") {
-            $s = sprintf('<input type="hidden" name="action_%s" value="true" />', htmlspecialchars($action, ENT_QUOTES));
+            $s = sprintf('<input type="hidden" name="action_%s" value="true">', htmlspecialchars($action, ENT_QUOTES));
         } else if ($type == "url") {
             $s = sprintf('action_%s=true', urlencode($action));
         }
@@ -1366,12 +1370,21 @@ class Ethna_Controller
     {
         $this->filter_chain = array();
         foreach ($this->filter as $filter) {
-            $filter_plugin =& $this->plugin->getPlugin('Filter', $filter);
-            if (Ethna::isError($filter_plugin)) {
-                continue;
-            }
+            //バージョン0.2.0以前のフィルタ群から探す
+            $file = sprintf("%s/%s.%s", $this->getDirectory('filter'), $filter,$this->getExt('php'));
+            if (file_exists($file)) {
+                include_once $file;
+                if (class_exists($filter)) {
+                    $this->filter_chain[] =& new $filter($this);
+                }
+            } else {  //プラグインから探す．
+                $filter_plugin =& $this->plugin->getPlugin('Filter', $filter);
+                if (Ethna::isError($filter_plugin)) {
+                    continue;
+                }
 
-            $this->filter_chain[] =& $filter_plugin;
+                $this->filter_chain[] =& $filter_plugin;
+            }
         }
     }
 
@@ -1650,7 +1663,7 @@ class Ethna_Controller
     {
         return str_replace('_', '/', $forward_name) . '.' . $this->ext['tpl'];
     }
-
+    
     /**
      *  テンプレートパス名から遷移名を取得する
      *
@@ -1717,8 +1730,71 @@ class Ethna_Controller
         if (is_object($this->renderer)) {
             return $this->renderer;
         }
-
+        
         $this->renderer =& $this->class_factory->getObject('renderer');
+       
+        // {{{ for B.C.
+        if (strtolower(get_class($this->renderer)) == "ethna_renderer_smarty") {
+            // user defined modifiers
+            foreach ($this->smarty_modifier_plugin as $modifier) {
+                if (!is_array($modifier)) {
+                    $name = str_replace('smarty_modifier_', '', $modifier);
+                    $this->renderer->setPlugin($name,'modifier', $modifier);
+                } else {
+                    $this->renderer->setPlugin($modifier[1], 'modifier', $modifier);
+                }
+            }
+
+            // user defined functions
+            foreach ($this->smarty_function_plugin as $function) {
+                if (!is_array($function)) {
+                    $name = str_replace('smarty_function_', '', $function);
+                    $this->renderer->setPlugin($name, 'function', $function);
+                } else {
+                    $this->renderer->setPlugin($function[1], 'function', $function);
+                }
+            }
+
+            // user defined blocks
+            foreach ($this->smarty_block_plugin as $block) {
+                if (!is_array($block)) {
+                    $name = str_replace('smarty_block_', '', $block);
+                    $this->renderer->setPlugin($name,'block', $block);
+                } else {
+                    $this->renderer->setPlugin($block[1],'block', $block);
+                }
+            }
+
+            // user defined prefilters
+            foreach ($this->smarty_prefilter_plugin as $prefilter) {
+                if (!is_array($prefilter)) {
+                    $name = str_replace('smarty_prefilter_', '', $prefilter);
+                    $this->renderer->setPlugin($name,'prefilter', $prefilter);
+                } else {
+                    $this->renderer->setPlugin($prefilter[1],'prefilter', $prefilter);
+                }
+            }
+
+            // user defined postfilters
+            foreach ($this->smarty_postfilter_plugin as $postfilter) {
+                if (!is_array($postfilter)) {
+                    $name = str_replace('smarty_postfilter_', '', $postfilter);
+                    $this->renderer->setPlugin($name,'postfilter', $postfilter);
+                } else {
+                    $this->renderer->setPlugin($postfilter[1],'postfilter', $postfilter);
+                }
+            }
+
+            // user defined outputfilters
+            foreach ($this->smarty_outputfilter_plugin as $outputfilter) {
+                if (!is_array($outputfilter)) {
+                    $name = str_replace('smarty_outputfilter_', '', $outputfilter);
+                    $this->renderer->setPlugin($name,'outputfilter', $outputfilter);
+                } else {
+                    $this->renderer->setPlugin($outputfilter[1],'outputfilter', $outputfilter);
+                }
+            }
+        }
 
         //テンプレートエンジンのデフォルトの設定
         $this->_setDefaultTemplateEngine($this->renderer);
@@ -1748,7 +1824,7 @@ class Ethna_Controller
      *                                      (ll_cc の形式。ll = 言語コード cc = 国コード)
      *  @param  string  $system_encoding    システムエンコーディング名
      *  @param  string  $client_encoding    クライアントエンコーディング(テンプレートのエンコーディングと考えれば良い)
-     *  @see    http://www.gnu.org/software/gettext/manual/html_node/Locale-Names.html
+     *  @see    http://www.gnu.org/software/gettext/manual/html_node/Locale-Names.html 
      *  @see    Ethna_Controller#_getDefaultLanguage
      */
     function _setLanguage($locale, $system_encoding = null, $client_encoding = null)
@@ -1757,9 +1833,6 @@ class Ethna_Controller
         $this->system_encoding = $system_encoding;
         $this->client_encoding = $client_encoding;
 
-        //   $this->locale, $this->client_encoding を書き換えた場合は
-        //   必ず Ethna_I18N クラスの setLanguageメソッドも呼ぶこと!
-        //   さもないとカタログその他が再ロードされない！
         $i18n =& $this->getI18N();
         $i18n->setLanguage($locale, $system_encoding, $client_encoding);
     }
@@ -1837,9 +1910,8 @@ class Ethna_Controller
     function getManagerClassName($name)
     {
         //   アプリケーションIDと、渡された名前のはじめを大文字にして、
-        //   組み合わせたものが返される
-        $manager_id = preg_replace('/_(.)/e', "strtoupper('\$1')", ucfirst($name));
-        return sprintf('%s_%sManager', $this->getAppId(), ucfirst($manager_id));
+        //   組み合わせたものが返される 
+        return sprintf('%s_%sManager', $this->getAppId(), ucfirst($name));
     }
 
     /**
@@ -1854,7 +1926,7 @@ class Ethna_Controller
         //  引数のはじめの一文字目と、アンダーバー直後の
         //  1文字を必ず大文字にする。アンダーバーは削除される。
         $name = preg_replace('/_(.)/e', "strtoupper('\$1')", ucfirst($name));
-
+        
         //  $name に foo_bar を渡し、AppID が Hogeの場合
         //  [Appid]_FooBar が返される
         return sprintf('%s_%s', $this->getAppId(), $name);
@@ -1898,9 +1970,15 @@ class Ethna_Controller
                 include_once $action_dir . $class_path;
             } else {
                 $this->logger->log(LOG_DEBUG, 'default action file not found [%s] -> try all files', $class_path);
-                return;
+                $class_path = null;
             }
         }
+        
+        // 全ファイルインクルード
+        if (is_null($class_path)) {
+            $this->_includeDirectory($this->getActiondir());
+            return;
+        }
 
         // form_path属性チェック
         if (isset($action_obj['form_path'])) {
@@ -2033,7 +2111,7 @@ class Ethna_Controller
 
     /**
      *  DSNのアクセス分岐を行う
-     *
+     *  
      *  スレーブサーバへの振分け処理(デフォルト:ランダム)を変更したい場合はこのメソッドをオーバーライドする
      *
      *  @access protected
@@ -2051,7 +2129,7 @@ class Ethna_Controller
         list($usec, $sec) = explode(' ', microtime());
         mt_srand($sec + ((float) $usec * 100000));
         $n = mt_rand(0, count($dsn_list)-1);
-
+        
         return $dsn_list[$n];
     }
 
@@ -2069,7 +2147,7 @@ class Ethna_Controller
         }
 
         require_once ETHNA_BASE . '/class/Ethna_InfoManager.php';
-
+        
         // see if we have simpletest
         if (file_exists_ex('simpletest/unit_tester.php', true)) {
             require_once ETHNA_BASE . '/class/Ethna_UnitTestManager.php';
@@ -2089,8 +2167,8 @@ class Ethna_Controller
             'view_name'     => 'Ethna_View_Info',
             'view_path'     => sprintf('%s/class/View/Ethna_View_Info.php', ETHNA_BASE),
         );
-
-
+        
+        
         // action設定
         $this->action['__ethna_unittest__'] = array(
             'form_name' =>  'Ethna_Form_UnitTest',
@@ -2143,7 +2221,7 @@ class Ethna_Controller
          echo "<br>";
          echo "In {$appid}-ini.php, please set as follows :<br><br>";
          echo "\$config = array ( 'debug' => true, );";
-     }
+     } 
 
     /**
      *  CLI実行中フラグを取得する
