@@ -6,7 +6,7 @@
  *  @author     ICHII Takashi <ichii386@schweetheart.jp>
  *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
  *  @package    Ethna
- *  @version    $Id$
+ *  @version    $Id: Ethna_PearWrapper.php 488 2007-12-13 22:11:18Z mumumu-org $
  */
 
 require_once 'PEAR.php';
@@ -454,7 +454,7 @@ class Ethna_PearWrapper
         $config =& PEAR_Config::singleton();
         $packagefile =& new PEAR_PackageFile($config);
         $info =& $packagefile->fromTgzFile($filename, PEAR_VALIDATE_NORMAL);
-        if (PEAR::isError($info)) {
+        if (Ethna::isError($info)) {
             return $info;
         }
         $info_array = $info->toArray();
@@ -648,9 +648,8 @@ class Ethna_PearWrapper
     {
         $short_args = $long_args = null;
         PEAR_Command::getGetOptArgs($cmd_str, $short_args, $long_args);
-        $opt = new Ethna_Getopt();
-        $opt_arg = $opt->getopt($opt_array, $short_args, $long_args);
-        if (Ethna::isError($opt_arg)) return array();
+        $opt_arg = Console_GetOpt::getOpt2($opt_array, $short_args, $long_args);
+        if (PEAR::isError($opt_arg)) return array();
         $opts = array();
         foreach ($opt_arg[0] as $tmp) {
             list($opt, $val) = $tmp;
