@@ -7,7 +7,7 @@
  *  @author     Kazuhiro Hosoi <hosoi@gree.co.jp>
  *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
  *  @package    Ethna
- *  @version    $Id$
+ *  @version    $Id: Ethna_Plugin.php 488 2007-12-13 22:11:18Z mumumu-org $
  */
 
 // {{{ Ethna_Plugin
@@ -388,11 +388,7 @@ class Ethna_Plugin
         // 後で見付かったもので上書きするので $this->appid_list の逆順とする
         $name_list = array();
         foreach (array_reverse($this->appid_list) as $appid) {
-            //  クラス名として許可された文字であればOKとする
-            //  アンダーバーを拒む理由はないし、命名規約からも禁止されていない
-            //  @see http://ethna.jp/ethna-document-dev_guide-plugin.html
-            //  @see http://www.php.net/manual/en/language.variables.php
-            list($class_regexp, $dir, $file_regexp) = $this->getPluginNaming($type, '([a-zA-Z0-9_\x7f-\xff]+)', $appid);
+            list($class_regexp, $dir, $file_regexp) = $this->getPluginNaming($type, '([^_]+)', $appid);
 
             //ディレクトリの存在のチェック
             if (is_dir($dir) == false) {
