@@ -5,14 +5,14 @@
  *  @author     Masaki Fujimoto <fujimoto@php.net>
  *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
  *  @package    Ethna
- *  @version    $Id: Ethna_SmartyPlugin.php 725 2009-02-05 16:59:45Z mumumu-org $
+ *  @version    $Id: Ethna_SmartyPlugin.php 580 2008-06-13 15:52:53Z mumumu-org $
  */
 
 // {{{ smarty_modifier_number_format
 /**
  *  smarty modifier:number_format()
  *
- *  number_format()ؿwrapper
+ *  number_format()関数のwrapper
  *
  *  sample:
  *  <code>
@@ -22,8 +22,8 @@
  *  12,345
  *  </code>
  *
- *  @param  string  $string եޥåоʸ
- *  @return string  եޥåȺѤʸ
+ *  @param  string  $string フォーマット対象文字列
+ *  @return string  フォーマット済み文字列
  */
 function smarty_modifier_number_format($string)
 {
@@ -38,19 +38,19 @@ function smarty_modifier_number_format($string)
 /**
  *  smarty modifier:strftime()
  *
- *  strftime()ؿwrapper
+ *  strftime()関数のwrapper
  *
  *  sample:
  *  <code>
- *  {"2004/01/01 01:01:01"|strftime:"%Yǯ%m%d"}
+ *  {"2004/01/01 01:01:01"|strftime:"%Y年%m月%d日"}
  *  </code>
  *  <code>
- *  2004ǯ0101
+ *  2004年01月01日
  *  </code>
  *
- *  @param  string  $string եޥåоʸ
- *  @param  string  $format 񼰻ʸ(strftime()ؿ)
- *  @return string  եޥåȺѤʸ
+ *  @param  string  $string フォーマット対象文字列
+ *  @param  string  $format 書式指定文字列(strftime()関数参照)
+ *  @return string  フォーマット済み文字列
  */
 function smarty_modifier_strftime($string, $format)
 {
@@ -65,7 +65,7 @@ function smarty_modifier_strftime($string, $format)
 /**
  *  smarty modifier:count()
  *
- *  count()ؿwrapper
+ *  count()関数のwrapper
  *
  *  sample:
  *  <code>
@@ -77,8 +77,8 @@ function smarty_modifier_strftime($string, $format)
  *  3
  *  </code>
  *
- *  @param  array   $array  оݤȤʤ
- *  @return int     ǿ
+ *  @param  array   $array  対象となる配列
+ *  @return int     配列の要素数
  */
 function smarty_modifier_count($array)
 {
@@ -90,7 +90,7 @@ function smarty_modifier_count($array)
 /**
  *  smarty modifier:join()
  *
- *  join()ؿwrapper
+ *  join()関数のwrapper
  *
  *  sample:
  *  <code>
@@ -102,9 +102,9 @@ function smarty_modifier_count($array)
  *  1:2:3
  *  </code>
  *
- *  @param  array   $array  joinоݤ
- *  @param  string  $glue   Ϣʸ
- *  @return string  Ϣʸ
+ *  @param  array   $array  join対象の配列
+ *  @param  string  $glue   連結文字列
+ *  @return string  連結後の文字列
  */
 function smarty_modifier_join($array, $glue)
 {
@@ -119,7 +119,7 @@ function smarty_modifier_join($array, $glue)
 /**
  *  smarty modifier:filter()
  *
- *  ꤵ줿ϢΤ$keyǻꤵ줿ǤΤߤ˺ƹ
+ *  指定された連想配列のうち$keyで指定された要素のみを配列に再構成する
  *
  *  sample:
  *  <code>
@@ -135,9 +135,9 @@ function smarty_modifier_join($array, $glue)
  *  1,2,3
  *  </code>
  *  
- *  @param  array   $array  filterоݤȤʤ
- *  @param  string  $key    ȴФϢΥ
- *  @return array   ƹ줿
+ *  @param  array   $array  filter対象となる配列
+ *  @param  string  $key    抜き出して配列を構成する連想配列のキー
+ *  @return array   再構成された配列
  */
 function smarty_modifier_filter($array, $key)
 {
@@ -159,7 +159,7 @@ function smarty_modifier_filter($array, $key)
 /**
  *  smarty modifier:unique()
  *
- *  unique()ؿwrapper
+ *  unique()関数のwrapper
  *
  *  sample:
  *  <code>
@@ -181,9 +181,9 @@ function smarty_modifier_filter($array, $key)
  *  123
  *  </code>
  *  
- *  @param  array   $array  оݤȤʤ
- *  @param  key     $key    оݤȤʤ륭(nullʤ)
- *  @return array   ƹ줿
+ *  @param  array   $array  処理対象となる配列
+ *  @param  key     $key    処理対象となるキー(nullなら配列要素)
+ *  @return array   再構成された配列
  */
 function smarty_modifier_unique($array, $key = null)
 {
@@ -196,9 +196,9 @@ function smarty_modifier_unique($array, $key = null)
             if (isset($v[$key]) == false) {
                 continue;
             }
-            $tmp[] = $v[$key];
+            $tmp[$v[$key]] = $v;
         }
-        return array_unique($tmp);
+        return $tmp;
     } else {
         return array_unique($array);
     }
@@ -207,32 +207,38 @@ function smarty_modifier_unique($array, $key = null)
 
 // {{{ smarty_modifier_wordwrap_i18n
 /**
- *  smarty modifier:ʸwordwrap
- *
- *  [EUC-JPбEUC-JPΤб]
+ *  smarty modifier:文字列のwordwrap処理
  *
  *  sample:
  *  <code>
- *  {"aaaaaa"|wordrap_i18n:8}
+ *  {"あいうaえaおaかきaaaくけこ"|wordrap_i18n:8}
  *  </code>
  *  <code>
- *  a
- *  aa
- *  aaa
- *  
+ *  あいうa
+ *  えaおaか
+ *  きaaaく
+ *  けこ
  *  </code>
  *
- *  @param  string  $string wordwrapʸ
- *  @param  string  $break  ʸ
- *  @param  int     $width  wordwrap(Ⱦ$widthʸwordwrap)
- *  @param  int     $indent ǥ(Ⱦ$indentʸ)
- *  @return string  wordwrap줿ʸ
+ *  @param  string  $string wordwrapする文字列
+ *  @param  string  $break  改行文字
+ *  @param  int     $width  wordwrap幅(半角$width文字でwordwrapする)
+ *  @param  int     $indent インデント幅(半角$indent文字)
+ *                          数値を指定するが、はじめの行はインデントされない
+ *  @return string  wordwrap処理された文字列
  */
 function smarty_modifier_wordwrap_i18n($string, $width, $break = "\n", $indent = 0)
 {
+    $ctl =& Ethna_Controller::getInstance();
+    $client_enc = $ctl->getClientEncoding(); 
+
+    //    いわゆる半角を単位にしてwrapする位置を測るため、いったん
+    //    EUC_JP に変換する
+    $euc_string = mb_convert_encoding($string, 'EUC_JP', $client_enc);
+
     $r = "";
     $i = "$break" . str_repeat(" ", $indent);
-    $tmp = $string;
+    $tmp = $euc_string;
     do {
         $n = strpos($tmp, $break);
         if ($n !== false && $n < $width) {
@@ -242,9 +248,8 @@ function smarty_modifier_wordwrap_i18n($string, $width, $break = "\n", $indent =
             continue;
         }
 
-        $s = mb_strimwidth($tmp, 0, $width, "", "EUC-JP");
+        $s = mb_strimwidth($tmp, 0, $width, "", 'EUC_JP');
 
-        // EUC-JPΤб
         $n = strlen($s);
         if ($n >= $width && $tmp{$n} != "" && $tmp{$n} != " ") {
             while ((ord($s{$n-1}) & 0x80) == 0) {
@@ -262,24 +267,27 @@ function smarty_modifier_wordwrap_i18n($string, $width, $break = "\n", $indent =
 
     $r = preg_replace('/\s+$/', '', $r);
 
+    //    最後に、クライアントエンコーディングに変換
+    $r = mb_convert_encoding($r, $client_enc, 'EUC_JP');
+
     return $r;
 }
 // }}}
 
 // {{{ smarty_modifier_truncate_i18n
 /**
- *  smarty modifier:ʸڤͤ(i18nб)
+ *  smarty modifier:文字列切り詰め処理(i18n対応)
  *
  *  sample:
  *  <code>
- *  {"ܸǤ"|truncate_i18n:5:"..."}
+ *  {"日本語です"|truncate_i18n:5:"..."}
  *  </code>
  *  <code>
- *  ...
+ *  日本...
  *  </code>
  *
- *  @param  int     $len        ʸ
- *  @param  string  $postfix    ղäʸ
+ *  @param  int     $len        最大文字幅
+ *  @param  string  $postfix    末尾に付加する文字列
  */
 function smarty_modifier_truncate_i18n($string, $len = 80, $postfix = "...")
 {
@@ -289,18 +297,18 @@ function smarty_modifier_truncate_i18n($string, $len = 80, $postfix = "...")
 
 // {{{ smarty_modifier_i18n
 /**
- *  smarty modifier:i18nե륿
+ *  smarty modifier:i18nフィルタ
  *
  *  sample:
  *  <code>
  *  {"english"|i18n}
  *  </code>
  *  <code>
- *  Ѹ
+ *  英語
  *  </code>
  *
- *  @param  string  $string i18nоݤʸ
- *  @return string  бå
+ *  @param  string  $string i18n処理対象の文字列
+ *  @return string  ロケールに対応したメッセージ
  */
 function smarty_modifier_i18n($string)
 {
@@ -314,7 +322,7 @@ function smarty_modifier_i18n($string)
 
 // {{{ smarty_modifier_checkbox
 /**
- *  smarty modifier:åܥåѥե륿
+ *  smarty modifier:チェックボックス用フィルタ
  *
  *  sample:
  *  <code>
@@ -323,26 +331,26 @@ function smarty_modifier_i18n($string)
  *  </code>
  *  <code>
  *  <input type="checkbox" name="test">
- *  <input type="checkbox" name="test" checked>
+ *  <input type="checkbox" name="test" checkbox>
  *  </code>
  *
- *  @param  string  $string åܥåϤ줿ե(顼Τ)
- *  @return string  $stringʸ󤢤뤤0, null, false ʳξ"checked"
+ *  @param  string  $string チェックボックスに渡されたフォーム値
+ *  @return string  $stringが空文字列あるいは0以外の場合は"checked"
  */
 function smarty_modifier_checkbox($string)
 {
-    if (is_scalar($string) && $string != "" && $string != "0") {
-        return 'checked="checked"';
+    if ($string != "" && $string != 0) {
+        return "checked";
     }
 }
 // }}}
 
 // {{{ smarty_modifier_select
 /**
- *  smarty modifier:쥯ȥܥåѥե륿
+ *  smarty modifier:セレクトボックス用フィルタ
  *
- *  ñʥ쥯ȥܥåξsmartyؿ"select"Ѥ뤳Ȥ
- *  άǽ
+ *  単純なセレクトボックスの場合はsmarty関数"select"を利用することで
+ *  タグを省略可能
  *
  *  sample:
  *  <code>
@@ -352,17 +360,17 @@ function smarty_modifier_checkbox($string)
  *  <option value="2" {$form|select:"2"}>bar</option>
  *  </code>
  *  <code>
- *  <option value="1" selected="selected">foo</option>
+ *  <option value="1" selected>foo</option>
  *  <option value="2" >bar</option>
  *  </code>
  *
- *  @param  string  $string 쥯ȥܥåϤ줿ե
- *  @param  string  $value  <option>˻ꤵƤ
- *  @return string  $string$value˥ޥå"selected"
+ *  @param  string  $string セレクトボックスに渡されたフォーム値
+ *  @param  string  $value  <option>タグに指定されている値
+ *  @return string  $stringが$valueにマッチする場合は"selected"
  */
 function smarty_modifier_select($string, $value)
 {
-    //    ɸ˹碌
+    //    標準に合わせる
     //    @see http://www.w3.org/TR/html401/interact/forms.html#adef-selected
     //    @see http://www.w3.org/TR/2000/REC-xhtml1-20000126/DTD/xhtml1-transitional.dtd
     //    @see http://www.w3.org/TR/2000/REC-xhtml1-20000126/DTD/xhtml1-strict.dtd
@@ -376,9 +384,9 @@ function smarty_modifier_select($string, $value)
 
 // {{{ smarty_modifier_form_value
 /**
- *  smarty modifier:եͽϥե륿
+ *  smarty modifier:フォーム値出力フィルタ
  *
- *  ե̾ѿǻꤷƥեͤ˻Ѥ
+ *  フォーム名を変数で指定してフォーム値を取得したい場合に使用する
  *
  *  sample:
  *  <code>
@@ -390,8 +398,8 @@ function smarty_modifier_select($string, $value)
  *  bar
  *  </code>
  *
- *  @param  string  $string ե̾
- *  @return string  ե
+ *  @param  string  $string フォーム項目名
+ *  @return string  フォーム値
  */
 function smarty_modifier_form_value($string)
 {
@@ -410,11 +418,11 @@ function smarty_modifier_form_value($string)
 
 // {{{ smarty_function_is_error
 /**
- *  smarty function:ꤵ줿եܤǥ顼ȯƤ뤫ɤ֤
- *  NOTE: {if is_error('name')}  Ethna_Util.php  is_error() Ǥäơ
- *        smarty_function_is_error() ǤϤʤȤ
+ *  smarty function:指定されたフォーム項目でエラーが発生しているかどうかを返す
+ *  NOTE: {if is_error('name')} は Ethna_Util.php の is_error() であって、
+ *        smarty_function_is_error() ではないことに注意
  *
- *  @param  string  $name   ե̾
+ *  @param  string  $name   フォーム項目名
  */
 function smarty_function_is_error($params, &$smarty)
 {
@@ -425,17 +433,17 @@ function smarty_function_is_error($params, &$smarty)
 
 // {{{ smarty_function_message
 /**
- *  smarty function:ꤵ줿եܤб륨顼åϤ
+ *  smarty function:指定されたフォーム項目に対応するエラーメッセージを出力する
  *
  *  sample:
  *  <code>
  *  <input type="text" name="foo">{message name="foo"}
  *  </code>
  *  <code>
- *  <input type="text" name="foo">fooϤƤ
+ *  <input type="text" name="foo">fooを入力してください
  *  </code>
  *
- *  @param  string  $name   ե̾
+ *  @param  string  $name   フォーム項目名
  */
 function smarty_function_message($params, &$smarty)
 {
@@ -461,7 +469,7 @@ function smarty_function_message($params, &$smarty)
 
 // {{{ smarty_function_uniqid
 /**
- *  smarty function:ˡID(double postå)
+ *  smarty function:ユニークIDを生成する(double postチェック用)
  *
  *  sample:
  *  <code>
@@ -471,7 +479,7 @@ function smarty_function_message($params, &$smarty)
  *  <input type="hidden" name="uniqid" value="a0f24f75e...e48864d3e">
  *  </code>
  *
- *  @param  string  $type   ɽ("get" or "post"ݥǥե="post")
+ *  @param  string  $type   表示タイプ("get" or "post"−デフォルト="post")
  *  @see    isDuplicatePost
  */
 function smarty_function_uniqid($params, &$smarty)
@@ -487,30 +495,12 @@ function smarty_function_uniqid($params, &$smarty)
 
 // {{{ smarty_function_select
 /**
- *  smarty function:쥯ȥե
+ *  smarty function:セレクトフィールド生成
  *
- *  sample:
- *  <code>
- *  $smarty->assign('hoge',
- *                   array(
- *                       '1' => array('name' => 'foo'),
- *                       '2' => array('name' => 'bar')
- *                   )
- *  );
- *  {select list=$hoge name="hoge" value="1" empty="-- please select --"}
- *  </code>
- *  <code>
- *  <select name="hoge">
- *    <option value="">-- please select --</option>
- *    <option value="1" selected="selected">foo</option>
- *    <option value="2">bar</option>
- *  </select>
- *  </code>
- *
- *  @param  array   $list   
- *  @param  string  $name   ե̾
- *  @param  string  $value  쥯ȥܥåϤ줿ե
- *  @param  string  $empty  ȥ(---򤷤Ʋ---)
+ *  @param  array   $list   選択肢一覧
+ *  @param  string  $name   フォーム項目名
+ *  @param  string  $value  セレクトボックスに渡されたフォーム値
+ *  @param  string  $empty  空エントリ(「---選択して下さい---」等)
  *  @deprecated
  */
 function smarty_function_select($params, &$smarty)
@@ -522,7 +512,7 @@ function smarty_function_select($params, &$smarty)
         printf("<option value=\"\">%s</option>\n", $empty);
     }
     foreach ($list as $id => $elt) {
-        printf("<option value=\"%s\" %s>%s</option>\n", $id, $id == $value ? 'selected="selected"' : '', $elt['name']);
+        printf("<option value=\"%s\" %s>%s</option>\n", $id, $id == $value ? 'selected="true"' : '', $elt['name']);
     }
     print "</select>\n";
 }
@@ -530,11 +520,11 @@ function smarty_function_select($params, &$smarty)
 
 // {{{ smarty_function_checkbox_list
 /**
- *  smarty function:åܥåե륿ؿ(б)
+ *  smarty function:チェックボックスフィルタ関数(配列対応)
  *
- *  @param  string  $form   åܥåϤ줿ե
- *  @param  string  $key    ɾоݤ󥤥ǥå
- *  @param  string  $value  ɾ
+ *  @param  string  $form   チェックボックスに渡されたフォーム値
+ *  @param  string  $key    評価対象の配列インデックス
+ *  @param  string  $value  評価値
  *  @deprecated
  */
 function smarty_function_checkbox_list($params, &$smarty)
@@ -577,7 +567,7 @@ function smarty_function_checkbox_list($params, &$smarty)
 
 // {{{ smarty_function_url
 /**
- *  smarty function:url
+ *  smarty function:url生成
  */
 function smarty_function_url($params, &$smarty)
 {
@@ -628,9 +618,9 @@ function smarty_function_url($params, &$smarty)
 
 // {{{ smarty_function_form_name
 /**
- *  smarty function:եɽ̾
+ *  smarty function:フォーム表示名生成
  *
- *  @param  string  $name   ե̾
+ *  @param  string  $name   フォーム項目名
  */
 function smarty_function_form_name($params, &$smarty)
 {
@@ -674,9 +664,9 @@ function smarty_function_form_name($params, &$smarty)
 
 // {{{ smarty_function_form_submit
 /**
- *  smarty function:եsubmitܥ
+ *  smarty function:フォームのsubmitボタン生成
  *
- *  @param  string  $submit   ե̾
+ *  @param  string  $submit   フォーム項目名
  */
 function smarty_function_form_submit($params, &$smarty)
 {
@@ -691,9 +681,9 @@ function smarty_function_form_submit($params, &$smarty)
 
 // {{{ smarty_function_form_input
 /**
- *  smarty function:եॿ
+ *  smarty function:フォームタグ生成
  *
- *  @param  string  $name   ե̾
+ *  @param  string  $name   フォーム項目名
  */
 function smarty_function_form_input($params, &$smarty)
 {
@@ -712,7 +702,7 @@ function smarty_function_form_input($params, &$smarty)
         return null;
     }
 
-    // ߤ{form_input}Ϥform blockХѥ᡼Ƥ
+    // 現在の{form_input}を囲むform blockがあればパラメータを取得しておく
     $block_params = null;
     for ($i = count($smarty->_tag_stack); $i >= 0; --$i) {
         if ($smarty->_tag_stack[$i][0] === 'form') {
@@ -735,16 +725,16 @@ function smarty_function_form_input($params, &$smarty)
 
     // default
     if (isset($params['default'])) {
-        // {form_input default=...}ꤵƤФΤޤ
+        // {form_input default=...}が指定されていればそのまま
 
     } else if (isset($block_params['default'])) {
-        // ¦ {form default=...} ֥å
+        // 外側の {form default=...} ブロック
         if (isset($block_params['default'][$name])) {
             $params['default'] = $block_params['default'][$name];
         }
     }
 
-    // ߤΥǼäե
+    // 現在のアクションで受け取ったフォーム値
     $af =& $c->getActionForm();
     $val = $af->get($name);
     if ($val !== null) {
@@ -757,16 +747,16 @@ function smarty_function_form_input($params, &$smarty)
 
 // {{{ smarty_block_form
 /**
- *  smarty block:եॿϥץ饰
+ *  smarty block:フォームタグ出力プラグイン
  */
 function smarty_block_form($params, $content, &$smarty, &$repeat)
 {
     if ($repeat) {
-        // {form}: ֥å˿ʤν
+        // {form}: ブロック内部に進む前の処理
 
         // default
         if (isset($params['default']) === false) {
-            // ʤΤȤ $form Ȥ
+            // 指定なしのときは $form を使う
             $c =& Ethna_Controller::getInstance();
             $af =& $c->getActionForm();
 
@@ -775,11 +765,11 @@ function smarty_block_form($params, $content, &$smarty, &$repeat)
                 =& $af->getArray(false);
         }
 
-        // ֤ͤϽϤʤ
+        // ここで返す値は出力されない
         return '';
 
     } else {
-        // {/form}: ֥åΤ
+        // {/form}: ブロック全体を出力
 
         $c =& Ethna_Controller::getInstance();
         $view =& $c->getView();
@@ -797,7 +787,7 @@ function smarty_block_form($params, $content, &$smarty, &$repeat)
             $content = $hidden . $content;
         }
 
-        // enctype άб
+        // enctype の略称対応
         if (isset($params['enctype'])) {
             if ($params['enctype'] == 'file'
                 || $params['enctype'] == 'multipart') {
@@ -807,12 +797,12 @@ function smarty_block_form($params, $content, &$smarty, &$repeat)
             }
         }
 
-        // defaultϤ⤦
+        // defaultはもう不要
         if (isset($params['default'])) {
             unset($params['default']);
         }
 
-        // $contentϤ<form>֥åΤ
+        // $contentを囲む<form>ブロック全体を出力
         return $view->getFormBlock($content, $params);
     }
 }
@@ -820,7 +810,7 @@ function smarty_block_form($params, $content, &$smarty, &$repeat)
 
 // {{{ smarty_function_csrfid
 /**
- *  smarty function: ʥݥȤǤ뤳ȤݾڤIDϤ
+ *  smarty function: 正当なポストであることを保証するIDを出力する
  *
  *  sample:
  *  <code>
@@ -830,7 +820,7 @@ function smarty_block_form($params, $content, &$smarty, &$repeat)
  *  <input type="hidden" name="csrfid" value="a0f24f75e...e48864d3e">
  *  </code>
  *
- *  @param  string  $type   ɽ("get" or "post"ݥǥե="post")
+ *  @param  string  $type   表示タイプ("get" or "post"−デフォルト="post")
  *  @see    isRequestValid
  */
 function smarty_function_csrfid($params, &$smarty)
