@@ -6,7 +6,7 @@
  *  @author     Masaki Fujimoto <fujimoto@php.net>
  *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
  *  @package    Ethna
- *  @version    $Id$
+ *  @version    $Id: Ethna_Util.php 611 2008-07-05 01:13:48Z mumumu-org $
  */
 
 // {{{ to_array
@@ -87,7 +87,7 @@ function file_exists_ex($path, $use_include_path = true)
  */
 function is_absolute_path($path)
 {
-    if (ETHNA_OS_WINDOWS) {
+    if (OS_WINDOWS) {
         if (preg_match('/^[a-z]:/i', $path) && $path{2} == DIRECTORY_SEPARATOR) {
             return true;
         }
@@ -566,17 +566,17 @@ class Ethna_Util
             $srand = true;
         }
 
-        // open_basedir がオンで、かつ /proc が許可されているか？
-        // open_basedir が空なら許可されていると看做す
-        $devfile = '/proc/net/dev';
-        $open_basedir_conf = ini_get('open_basedir');
-        $devfile_enabled = (empty($open_basedir_conf) 
-                        || (preg_match('#:/proc#', $open_basedir_conf) > 0
-                        ||  preg_match('#^/proc#', $open_basedir_conf) > 0));
-
         $value = "";
         for ($i = 0; $i < 2; $i++) {
             // for Linux
+            // open_basedir がオンで、かつ /proc が許可されているか？
+            // open_basedir が空なら許可されていると看做す
+            $devfile = '/proc/net/dev';
+            $open_basedir_conf = ini_get('open_basedir');
+            $devfile_enabled = (empty($open_basedir_conf) 
+                            || (preg_match('#:/proc#', $open_basedir_conf) > 0
+                            ||  preg_match('#^/proc#', $open_basedir_conf) > 0));
+
             if ($devfile_enabled && file_exists($devfile)) {
                 $rx = $tx = 0;
                 $fp = fopen($devfile, 'r');
