@@ -6,7 +6,7 @@
  *  @author     Masaki Fujimoto <fujimoto@php.net>
  *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
  *  @package    Ethna
- *  @version    $Id$
+ *  @version    $Id: Ethna_ViewClass.php 601 2008-07-01 12:48:18Z mumumu-org $
  */
 
 // {{{ Ethna_ViewClass
@@ -23,9 +23,6 @@ class Ethna_ViewClass
      *  @access private
      */
 
-    /** @var    object  Ethna_Controller    Controllerオブジェクト */
-    var $ctl;
-
     /** @var    object  Ethna_Backend       backendオブジェクト */
     var $backend;
 
@@ -56,7 +53,7 @@ class Ethna_ViewClass
     /** @var    array   アクションフォームオブジェクト(helper) */
     var $helper_action_form = array();
 
-    /** @var    array   helperでhtmlのattributeにはしないパラメータの一覧 */
+    /** @var    array   helperでhtmlのattributeにはしなパラメータの一覧 */
     var $helper_parameter_keys = array('default', 'option', 'separator');
 
     /** @var    object  Ethna_Session       セッションオブジェクト */
@@ -68,9 +65,6 @@ class Ethna_ViewClass
     /** @var    string  遷移先テンプレートファイル名 */
     var $forward_path;
 
-    /** @var    boolean  配列フォームを呼んだカウンタをリセットするか否か */
-    var $reset_counter = false;
-
     /**#@-*/
 
     // {{{ Ethna_ViewClass
@@ -85,7 +79,6 @@ class Ethna_ViewClass
     function Ethna_ViewClass(&$backend, $forward_name, $forward_path)
     {
         $c =& $backend->getController();
-        $this->ctl =& $c;
         $this->backend =& $backend;
         $this->config =& $this->backend->getConfig();
         $this->i18n =& $this->backend->getI18N();
@@ -134,6 +127,7 @@ class Ethna_ViewClass
      */
     function forward()
     {
+        $this->_setLanguage();
         $renderer =& $this->_getRenderer();
         $this->_setDefault($renderer);
         $renderer->perform($this->forward_path);
@@ -144,41 +138,29 @@ class Ethna_ViewClass
     /**
      *  helperアクションフォームオブジェクトを設定する
      *
-     *  @param  string $action アクション名
-     *  @param  boolean $dynamic_helper 動的フォームヘルパを呼ぶか否か
      *  @access public
      */
-    function addActionFormHelper($action, $dynamic_helper = false)
+    function addActionFormHelper($action)
     {
-        //
-        //  既に追加されている場合は処理をしない
-        //
         if (isset($this->helper_action_form[$action])
             && is_object($this->helper_action_form[$action])) {
             return;
         }
 
-        //    現在のアクションと等しければ、対応する
-        //    アクションフォームを設定
         $ctl =& Ethna_Controller::getInstance();
         if ($action === $ctl->getCurrentActionName()) {
             $this->helper_action_form[$action] =& $this->af;
-        } else {
-            //    アクションが異なる場合
-            $form_name = $ctl->getActionFormName($action);
-            if ($form_name === null) {
-                $this->logger->log(LOG_WARNING,
-                    'action form for the action [%s] not found.', $action);
-                return;
-            }
-            $this->helper_action_form[$action] =& new $form_name($ctl);
+            return;
         }
 
-        //   動的フォームを設定するためのヘルパメソッドを呼ぶ
-        if ($dynamic_helper) {
-            $af =& $this->helper_action_form[$action];
-            $af->setFormDef_ViewHelper();
+        $form_name = $ctl->getActionFormName($action);
+        if ($form_name === null) {
+            $this->logger->log(LOG_WARNING,
+                'action form for the action [%s] not found.', $action);
+            return;
         }
+
+        $this->helper_action_form[$action] =& new $form_name($ctl);
     }
     // }}}
 
@@ -245,18 +227,6 @@ class Ethna_ViewClass
     }
     // }}}
 
-    // {{{ resetFormCounter
-    /**
-     *  フォームヘルパ用、内部フォームカウンタをリセットする
-     *
-     *  @access public
-     */
-    function resetFormCounter()
-    {
-        $this->reset_counter = true;
-    }
-    // }}}
-
     // {{{ getFormName
     /**
      *  指定されたフォーム項目に対応するフォーム名(w/ レンダリング)を取得する
@@ -321,11 +291,6 @@ class Ethna_ViewClass
         // 配列フォームが何回呼ばれたかを保存するカウンタ
         if (isset($def['type']) && is_array($def['type'])) {
             static $form_counter = array();
-            if ($this->reset_counter) {
-                $form_counter = array();
-                $this->reset_counter = false;
-            }
-
             if (isset($form_counter[$action]) === false) {
                 $form_counter[$action] = array();
             }
@@ -642,8 +607,10 @@ class Ethna_ViewClass
             $params['value'] = $value;
         }
 
-        //   maxlength と フォーム定義のmax連携はサポートしない
-        //   @see http://sourceforge.jp/ticket/browse.php?group_id=1343&tid=16325
+        // maxlength
+        if (isset($def['max']) && $def['max']) {
+            $params['maxlength'] = $def['max'];
+        }
 
         return $this->_getFormInput_Html('input', $params);
     }
@@ -829,6 +796,7 @@ class Ethna_ViewClass
         $element = '';
         if (isset($params['value'])) {
             $element = $params['value'];
+            unset($params['value']);
         } else if (isset($params['default'])) {
             $element = $params['default'];
         } else if (isset($def['default'])) {
@@ -840,6 +808,8 @@ class Ethna_ViewClass
             } else {
                 $element = '';
             }
+        } else {
+            $params['value'] = $element;
         }
 
         return $this->_getFormInput_Html('textarea', $params, $element);
@@ -883,8 +853,10 @@ class Ethna_ViewClass
             $params['value'] = $value;
         }
 
-        //   maxlength と フォーム定義のmax連携はサポートしない
-        //   @see http://sourceforge.jp/ticket/browse.php?group_id=1343&tid=16325
+        // maxlength
+        if (isset($def['max']) && $def['max']) {
+            $params['maxlength'] = $def['max'];
+        }
 
         return $this->_getFormInput_Html('input', $params);
     }
@@ -933,6 +905,21 @@ class Ethna_ViewClass
      *  @return object  Ethna_Renderer  レンダラオブジェクト
      */
     function &_getRenderer()
+    {
+        $_ret_object =& $this->_getTemplateEngine();
+        return $_ret_object;
+    }
+    // }}}
+
+    // {{{ _getTemplateEngine
+    /**
+     *  レンダラオブジェクトを取得する(そのうち_getRenderer()に統合される予定)
+     *
+     *  @access protected
+     *  @return object  Ethna_Renderer  レンダラオブジェクト
+     *  @obsolete
+     */
+    function &_getTemplateEngine()
     {
         $c =& $this->backend->getController();
         $renderer =& $c->getRenderer();
@@ -972,6 +959,19 @@ class Ethna_ViewClass
     {
     }
     // }}}
+
+    // {{{ _setLanguage
+    /**
+     *  言語設定を設定する。
+     *  アクションフォームやCookieの値等で、テンプレートや言語設定
+     *  を切り替えたい場合にオーバーライドしてください。
+     *
+     *  @access protected
+     */
+    function _setLanguage()
+    {
+    }
+    // }}}
 }
 // }}}
 ?>
