@@ -6,7 +6,7 @@
  *  @author     Masaki Fujimoto <fujimoto@php.net>
  *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
  *  @package    Ethna
- *  @version    $Id$
+ *  @version    $Id: Ethna_Plugin_Logwriter.php 602 2008-07-03 15:06:44Z mumumu-org $
  */
 
 // {{{ Ethna_Plugin_Logwriter
@@ -163,13 +163,6 @@ class Ethna_Plugin_Logwriter
             if (isset($bt[$i]['class']) == false) {
                 $bt[$i]['class'] = null;
             }
-            if (isset($bt[$i]['file']) == false) {
-                $bt[$i]['file'] = null;
-            }
-            if (isset($bt[$i]['line']) == false) {
-                $bt[$i]['line'] = null;
-            }
-
             $skip = false;
 
             // メソッドスキップ処理
