@@ -6,7 +6,7 @@
  *  @author     ICHII Takashi <ichii386@schweetheart.jp>
  *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
  *  @package    Ethna
- *  @version    $Id$
+ *  @version    $Id: Ethna_Plugin_Validator_Required.php 555 2008-05-26 14:06:58Z mumumu-org $
  */
 
 // {{{ Ethna_Plugin_Validator_Required
@@ -73,7 +73,7 @@ class Ethna_Plugin_Validator_Required extends Ethna_Plugin_Validator
         $valid_keys = array();
         if ($var != null) {
             foreach (array_keys($var) as $key) {
-                if ($this->isEmpty($var[$key], $this->getFormType($name)) == false) {
+                if ($this->isEmpty($var[$key], $form_def['type']) == false) {
                     $valid_keys[] = $key;
                 }
             }
