@@ -5,7 +5,7 @@
  *  @author     Takuya Ookubo <sfio@sakura.ai.to>
  *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
  *  @package    Ethna
- *  @version    $Id$
+ *  @version    $Id: Ethna_View_UnitTest.php 488 2007-12-13 22:11:18Z mumumu-org $
  */
 
 /**
@@ -25,10 +25,8 @@ class Ethna_View_UnitTest extends Ethna_ViewClass
     function preforward()
     {
         // タイムアウトしないように変更
-        if (!ini_get('safe_mode')) {
-            $max_execution_time = ini_get('max_execution_time');
-            set_time_limit(0);
-        }
+        $max_execution_time = ini_get('max_execution_time');
+        set_time_limit(0);
 
         if (!headers_sent()) {
             // キャッシュしない
@@ -47,9 +45,8 @@ class Ethna_View_UnitTest extends Ethna_ViewClass
 
         // include
         $file = sprintf("%s/%s_UnitTestManager.php",
-                        $ctl->getDirectory('app'),
-                        $ctl->getAppId()
-                );
+            $ctl->getDirectory('app'),
+            $ctl->getAppId());
         include_once $file;
 
         // run
@@ -62,10 +59,7 @@ class Ethna_View_UnitTest extends Ethna_ViewClass
         $this->af->setApp('result', $result);
 
         // タイムアウトを元に戻す
-        if (!ini_get('safe_mode')) {
-            set_time_limit($max_execution_time);
-        }
+        set_time_limit($max_execution_time);
     }
 }
-
 ?>
