@@ -4,7 +4,7 @@
  *
  *  @author     {$author}
  *  @package    {$project_id}
- *  @version    $Id$
+ *  @version    $Id: app.controller.php 596 2008-06-30 14:12:24Z mumumu-org $
  */
 
 /** Application base directory */
@@ -13,7 +13,7 @@ define('BASE', dirname(dirname(__FILE__)));
 /** include_path setting (adding "/app" and "/lib" directory to include_path) */
 $app = BASE . "/app";
 $lib = BASE . "/lib";
-set_include_path(implode(PATH_SEPARATOR, array($app, $lib)) . PATH_SEPARATOR . get_include_path());
+ini_set('include_path', implode(PATH_SEPARATOR, array($app, $lib)) . PATH_SEPARATOR . ini_get('include_path'));
 
 
 /** including application library. */
@@ -65,12 +65,7 @@ class {$project_id}_Controller extends Ethna_Controller
          *
          *  Example:
          *
-         *  'index'     => array(
-         *      'form_name' => 'Sample_Form_SomeAction',
-         *      'form_path' => 'Some/Action.php',
-         *      'class_name' => 'Sample_Action_SomeAction',
-         *      'class_path' => 'Some/Action.php',
-         *  ),
+         *  'index'     => array(),
          */
     );
 
@@ -100,7 +95,7 @@ class {$project_id}_Controller extends Ethna_Controller
         'filter'        => 'app/filter',
         'locale'        => 'locale',
         'log'           => 'log',
-        'plugins'       => array('app/plugin/Smarty',),
+        'plugins'       => array(),
         'template'      => 'template',
         'template_c'    => 'tmp',
         'tmp'           => 'tmp',
@@ -183,6 +178,84 @@ class {$project_id}_Controller extends Ethna_Controller
          */
     );
 
+    /**
+     *  @var    array   smarty modifier definition.
+     */
+    var $smarty_modifier_plugin = array(
+        /*
+         *  TODO: write user defined smarty modifier here.
+         *
+         *  Example:
+         *
+         *  'smarty_modifier_foo_bar',
+         */
+    );
+
+    /**
+     *  @var    array   smarty function definition.
+     */
+    var $smarty_function_plugin = array(
+        /*
+         *  TODO: write user defined smarty function here.
+         *
+         *  Example:
+         *
+         *  'smarty_function_foo_bar',
+         */
+    );
+
+    /**
+     *  @var    array   smarty block definition.
+     */
+    var $smarty_block_plugin = array(
+        /*
+         *  TODO: write user defined smarty block here.
+         *
+         *  Example:
+         * 
+         *  'smarty_block_foo_bar',
+         */
+    );
+
+    /**
+     *  @var    array   smarty prefilter definition.
+     */
+    var $smarty_prefilter_plugin = array(
+        /*
+         *  TODO: write user defined smarty prefilter here.
+         *
+         *  Example:
+         *
+         *  'smarty_prefilter_foo_bar',
+         */
+    );
+
+    /**
+     *  @var    array   smarty postfilter definition.
+     */
+    var $smarty_postfilter_plugin = array(
+        /*
+         *  TODO: write user defined smarty postfilter here.
+         *
+         *  Example:
+         *
+         *  'smarty_postfilter_foo_bar',
+         */
+    );
+
+    /**
+     *  @var    array   smarty outputfilter definition.
+     */
+    var $smarty_outputfilter_plugin = array(
+        /*
+         *  TODO: write user defined smarty outputfilter here.
+         *
+         *  Example:
+         *
+         *  'smarty_outputfilter_foo_bar',
+         */
+    );
+
     /**#@-*/
 
     /**
@@ -199,17 +272,6 @@ class {$project_id}_Controller extends Ethna_Controller
     {
         return array('{$locale}', 'UTF-8', '{$client_enc}');
     }
-
-    /**
-     *  テンプレートエンジンのデフォルト状態を設定する
-     *
-     *  @access protected
-     *  @param  object  Ethna_Renderer  レンダラオブジェクト
-     *  @obsolete
-     */
-    function _setDefaultTemplateEngine(&$renderer)
-    {
-    }
 }
 
 ?>
