@@ -5,7 +5,7 @@
  *
  *  @author     {$author}
  *  @package    {$project_id}
- *  @version    $Id$
+ *  @version    $Id: app.viewclass.php 600 2008-06-30 23:12:42Z mumumu-org $
  */
 
 // {{{ {$project_id}_ViewClass
@@ -28,6 +28,14 @@ class {$project_id}_ViewClass extends Ethna_ViewClass
     {
     }
 
+    /**
+     *  set language using actionform value, cookie ... etc.
+     *
+     *  @access protected
+     */
+    function _setLanguage()
+    {
+    }
 }
 // }}}
 
