@@ -4,17 +4,17 @@
  *
  *  @author     {$author}
  *  @package    {$project_id}
- *  @version    $Id$
+ *  @version    $Id: skel.app_manager.php 488 2007-12-13 22:11:18Z mumumu-org $
  */
 
 /**
- *  {$app_manager}
+ *  {$app_manager}Manager
  *
  *  @author     {$author}
  *  @access     public
  *  @package    {$project_id}
  */
-class {$app_manager} extends Ethna_AppManager
+class {$app_manager}Manager extends Ethna_AppManager
 {
 }
 ?>
